@@ -18,25 +18,6 @@ namespace Drupal\Component\Assertion;
  */
 class Inspector {
 
-  /**
-   * Asserts argument can be traversed with foreach.
-   *
-   * @param mixed $traversable
-   *   Variable to be examined.
-   *
-   * @return bool
-   *   TRUE if $traversable can be traversed with foreach.
-   *
-   * @deprecated in drupal:10.3.0 and is removed from drupal:11.0.0. Use
-   *   is_iterable() instead.
-   *
-   * @see https://www.drupal.org/node/3422775
-   */
-  public static function assertTraversable($traversable) {
-    @trigger_error(__METHOD__ . '() is deprecated in drupal:10.3.0 and is removed from drupal:11.0.0. Use is_iterable() instead. See https://www.drupal.org/node/3422775', E_USER_DEPRECATED);
-    return is_iterable($traversable);
-  }
-
   /**
    * Asserts callback returns TRUE for each member of a traversable.
    *
