@@ -373,7 +373,6 @@ abstract class EntityDisplayBase extends ConfigEntityBase implements EntityDispl
   /**
    * {@inheritdoc}
    */
-  #[ActionMethod(adminLabel: new TranslatableMarkup('Hide component'), name: 'hideComponent')]
   public function removeComponent($name) {
     $this->hidden[$name] = TRUE;
     unset($this->content[$name]);
@@ -548,7 +547,7 @@ abstract class EntityDisplayBase extends ConfigEntityBase implements EntityDispl
   /**
    * {@inheritdoc}
    */
-  public function __sleep() {
+  public function __sleep(): array {
     // Only store the definition, not external objects or derived data.
     $keys = array_keys($this->toArray());
     // In addition, we need to keep the entity type and the "is new" status.
@@ -567,7 +566,7 @@ abstract class EntityDisplayBase extends ConfigEntityBase implements EntityDispl
   /**
    * {@inheritdoc}
    */
-  public function __wakeup() {
+  public function __wakeup(): void {
     // Determine what were the properties from toArray() that were saved in
     // __sleep().
     $keys = $this->_serializedKeys;
@@ -588,20 +587,4 @@ abstract class EntityDisplayBase extends ConfigEntityBase implements EntityDispl
     return \Drupal::logger('system');
   }
 
-  /**
-   * {@inheritdoc}
-   */
-  public function set($property_name, $value): static {
-    // If changing the entity ID, also update the target entity type, bundle,
-    // and view mode.
-    if ($this->isNew() && $property_name === $this->getEntityType()->getKey('id')) {
-      if (substr_count($value, '.') !== 2) {
-        throw new \InvalidArgumentException("'$value' is not a valid entity display ID.");
-      }
-      [$this->targetEntityType, $this->bundle, $this->mode] = explode('.', $value);
-    }
-    parent::set($property_name, $value);
-    return $this;
-  }
-
 }
