@@ -3,7 +3,7 @@
 namespace Drupal\Core\Entity;
 
 use Drupal\Component\Plugin\Definition\PluginDefinition;
-use Drupal\Component\Utility\Unicode;
+use Drupal\Core\DependencyInjection\DependencySerializationTrait;
 use Drupal\Core\Entity\Exception\EntityTypeIdLengthException;
 use Drupal\Core\StringTranslation\StringTranslationTrait;
 use Drupal\Core\StringTranslation\TranslatableMarkup;
@@ -15,6 +15,7 @@ use Drupal\Core\StringTranslation\TranslatableMarkup;
  */
 class EntityType extends PluginDefinition implements EntityTypeInterface {
 
+  use DependencySerializationTrait;
   use StringTranslationTrait;
 
   /**
@@ -22,6 +23,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    *
    * @var bool
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $static_cache = TRUE;
 
   /**
@@ -29,6 +31,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    *
    * @var bool
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $render_cache = TRUE;
 
   /**
@@ -36,6 +39,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    *
    * @var bool
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $persistent_cache = TRUE;
 
   /**
@@ -43,6 +47,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    *
    * @var array
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $entity_keys = [];
 
   /**
@@ -73,8 +78,17 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    *
    * @var string
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $admin_permission;
 
+  /**
+   * The name of the collection permission.
+   *
+   * @var string
+   */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
+  protected $collection_permission;
+
   /**
    * The permission granularity level.
    *
@@ -82,6 +96,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    *
    * @var string
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $permission_granularity = 'entity_type';
   /**
    * Link templates using the URI template syntax.
@@ -90,26 +105,12 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    */
   protected $links = [];
 
-  /**
-   * The name of a callback that returns the label of the entity.
-   *
-   * @var callable|null
-   *
-   * @deprecated in Drupal 8.0.x-dev and will be removed before Drupal 9.0.0.
-   *   Use Drupal\Core\Entity\EntityInterface::label() for complex label
-   *   generation as needed.
-   *
-   * @see \Drupal\Core\Entity\EntityInterface::label()
-   *
-   * @todo Remove usages of label_callback https://www.drupal.org/node/2450793.
-   */
-  protected $label_callback = NULL;
-
   /**
    * The name of the entity type which provides bundles.
    *
    * @var string
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $bundle_entity_type = NULL;
 
   /**
@@ -117,6 +118,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    *
    * @var string|null
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $bundle_of = NULL;
 
   /**
@@ -124,6 +126,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    *
    * @var string|null
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $bundle_label = NULL;
 
   /**
@@ -131,6 +134,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    *
    * @var string|null
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $base_table = NULL;
 
   /**
@@ -138,6 +142,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    *
    * @var string|null
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $revision_data_table = NULL;
 
   /**
@@ -145,6 +150,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    *
    * @var string|null
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $revision_table = NULL;
 
   /**
@@ -152,8 +158,16 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    *
    * @var string|null
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $data_table = NULL;
 
+  /**
+   * Indicates whether the entity data is internal.
+   *
+   * @var bool
+   */
+  protected $internal = FALSE;
+
   /**
    * Indicates whether entities of this type have multilingual support.
    *
@@ -166,12 +180,13 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    *
    * @var bool
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $show_revision_ui = FALSE;
 
   /**
    * The human-readable name of the type.
    *
-   * @var string
+   * @var string|\Drupal\Core\StringTranslation\TranslatableMarkup
    *
    * @see \Drupal\Core\Entity\EntityTypeInterface::getLabel()
    */
@@ -180,39 +195,49 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
   /**
    * The human-readable label for a collection of entities of the type.
    *
-   * @var string
+   * @var string|\Drupal\Core\StringTranslation\TranslatableMarkup
    *
    * @see \Drupal\Core\Entity\EntityTypeInterface::getCollectionLabel()
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $label_collection = '';
 
   /**
    * The indefinite singular name of the type.
    *
-   * @var string
+   * @var string|\Drupal\Core\StringTranslation\TranslatableMarkup
    *
    * @see \Drupal\Core\Entity\EntityTypeInterface::getSingularLabel()
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $label_singular = '';
 
   /**
    * The indefinite plural name of the type.
    *
-   * @var string
+   * @var string|\Drupal\Core\StringTranslation\TranslatableMarkup
    *
    * @see \Drupal\Core\Entity\EntityTypeInterface::getPluralLabel()
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $label_plural = '';
 
   /**
    * A definite singular/plural name of the type.
    *
-   * Needed keys: "singular" and "plural".
+   * Needed keys: "singular" and "plural". Can also have key: "context".
+   * @code
+   * [
+   *    'singular' => '@count entity',
+   *    'plural' => '@count entities',
+   *    'context' => 'Entity context',
+   * ]
    *
    * @var string[]
    *
    * @see \Drupal\Core\Entity\EntityTypeInterface::getCountLabel()
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $label_count = [];
 
   /**
@@ -220,16 +245,26 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    *
    * @var callable|null
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $uri_callback = NULL;
 
   /**
    * The machine name of the entity type group.
+   *
+   * @var string
+   *
+   * @see self::getGroup()
    */
   protected $group;
 
   /**
    * The human-readable name of the entity type group.
+   *
+   * @var string|\Drupal\Core\StringTranslation\TranslatableMarkup
+   *
+   * @see \Drupal\Core\Entity\EntityTypeInterface::getGroupLabel()
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $group_label;
 
   /**
@@ -237,6 +272,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    *
    * @var string
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $field_ui_base_route;
 
   /**
@@ -247,6 +283,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    *
    * @var bool
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $common_reference_target = FALSE;
 
   /**
@@ -254,6 +291,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    *
    * @var string[]
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $list_cache_contexts = [];
 
   /**
@@ -261,6 +299,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    *
    * @var string[]
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName
   protected $list_cache_tags = [];
 
   /**
@@ -288,7 +327,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    */
   public function __construct($definition) {
     // Throw an exception if the entity type ID is longer than 32 characters.
-    if (Unicode::strlen($definition['id']) > static::ID_MAX_LENGTH) {
+    if (mb_strlen($definition['id']) > static::ID_MAX_LENGTH) {
       throw new EntityTypeIdLengthException('Attempt to create an entity type with an ID longer than ' . static::ID_MAX_LENGTH . " characters: {$definition['id']}.");
     }
 
@@ -311,11 +350,16 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
       $this->checkStorageClass($this->handlers['storage']);
     }
 
-    // Automatically add the EntityChanged constraint if the entity type tracks
-    // the changed time.
-    if ($this->entityClassImplements(EntityChangedInterface::class) ) {
+    // Automatically add the "EntityChanged" constraint if the entity type
+    // tracks the changed time.
+    if ($this->entityClassImplements(EntityChangedInterface::class)) {
       $this->addConstraint('EntityChanged');
     }
+    // Automatically add the "EntityUntranslatableFields" constraint if we have
+    // an entity type supporting translatable fields and pending revisions.
+    if ($this->entityClassImplements(ContentEntityInterface::class)) {
+      $this->addConstraint('EntityUntranslatableFields');
+    }
 
     // Ensure a default list cache tag is set.
     if (empty($this->list_cache_tags)) {
@@ -328,10 +372,10 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    */
   public function get($property) {
     if (property_exists($this, $property)) {
-      $value = isset($this->{$property}) ? $this->{$property} : NULL;
+      $value = $this->{$property} ?? NULL;
     }
     else {
-      $value = isset($this->additional[$property]) ? $this->additional[$property] : NULL;
+      $value = $this->additional[$property] ?? NULL;
     }
     return $value;
   }
@@ -349,6 +393,13 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
     return $this;
   }
 
+  /**
+   * {@inheritdoc}
+   */
+  public function isInternal() {
+    return $this->internal;
+  }
+
   /**
    * {@inheritdoc}
    */
@@ -382,7 +433,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    */
   public function getKey($key) {
     $keys = $this->getKeys();
-    return isset($keys[$key]) ? $keys[$key] : FALSE;
+    return $keys[$key] ?? FALSE;
   }
 
   /**
@@ -420,13 +471,6 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
     return is_subclass_of($this->getClass(), $interface);
   }
 
-  /**
-   * {@inheritdoc}
-   */
-  public function isSubclassOf($class) {
-    return $this->entityClassImplements($class);
-  }
-
   /**
    * {@inheritdoc}
    */
@@ -442,6 +486,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
       $handlers = $this->getHandlerClasses();
       return $nested ? $handlers[$handler_type][$nested] : $handlers[$handler_type];
     }
+    return NULL;
   }
 
   /**
@@ -595,6 +640,13 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
     return $this->admin_permission ?: FALSE;
   }
 
+  /**
+   * {@inheritdoc}
+   */
+  public function getCollectionPermission(): ?string {
+    return $this->collection_permission;
+  }
+
   /**
    * {@inheritdoc}
    */
@@ -614,7 +666,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    */
   public function getLinkTemplate($key) {
     $links = $this->getLinkTemplates();
-    return isset($links[$key]) ? $links[$key] : FALSE;
+    return $links[$key] ?? FALSE;
   }
 
   /**
@@ -637,28 +689,6 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
     return $this;
   }
 
-  /**
-   * {@inheritdoc}
-   */
-  public function getLabelCallback() {
-    return $this->label_callback;
-  }
-
-  /**
-   * {@inheritdoc}
-   */
-  public function setLabelCallback($callback) {
-    $this->label_callback = $callback;
-    return $this;
-  }
-
-  /**
-   * {@inheritdoc}
-   */
-  public function hasLabelCallback() {
-    return isset($this->label_callback);
-  }
-
   /**
    * {@inheritdoc}
    */
@@ -677,7 +707,15 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    * {@inheritdoc}
    */
   public function getBundleLabel() {
-    return (string) $this->bundle_label;
+    // If there is no bundle label defined, try to provide some sensible
+    // fallbacks.
+    if (!empty($this->bundle_label)) {
+      return (string) $this->bundle_label;
+    }
+    elseif ($bundle_entity_type_id = $this->getBundleEntityType()) {
+      return (string) \Drupal::entityTypeManager()->getDefinition($bundle_entity_type_id)->getLabel();
+    }
+    return (string) new TranslatableMarkup('@type_label bundle', ['@type_label' => $this->getLabel()], [], $this->getStringTranslation());
   }
 
   /**
@@ -737,13 +775,6 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
     return $this->label;
   }
 
-  /**
-   * {@inheritdoc}
-   */
-  public function getLowercaseLabel() {
-    return Unicode::strtolower($this->getLabel());
-  }
-
   /**
    * {@inheritdoc}
    */
@@ -760,7 +791,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    */
   public function getSingularLabel() {
     if (empty($this->label_singular)) {
-      $lowercase_label = $this->getLowercaseLabel();
+      $lowercase_label = mb_strtolower($this->getLabel());
       $this->label_singular = $lowercase_label;
     }
     return $this->label_singular;
@@ -771,7 +802,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    */
   public function getPluralLabel() {
     if (empty($this->label_plural)) {
-      $lowercase_label = $this->getLowercaseLabel();
+      $lowercase_label = $this->getSingularLabel();
       $this->label_plural = new TranslatableMarkup('@label entities', ['@label' => $lowercase_label], [], $this->getStringTranslation());
     }
     return $this->label_plural;
@@ -782,10 +813,13 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
    */
   public function getCountLabel($count) {
     if (empty($this->label_count)) {
-      return $this->formatPlural($count, '@count @label', '@count @label entities', ['@label' => $this->getLowercaseLabel()], ['context' => 'Entity type label']);
+      return $this->formatPlural($count, '@count @label', '@count @label entities', ['@label' => $this->getSingularLabel()], ['context' => 'Entity type label']);
     }
-    $context = isset($this->label_count['context']) ? $this->label_count['context'] : 'Entity type label';
-    return $this->formatPlural($count, $this->label_count['singular'], $this->label_count['plural'], ['context' => $context]);
+    $options = [];
+    if (isset($this->label_count['context'])) {
+      $options['context'] = $this->label_count['context'];
+    }
+    return $this->formatPlural($count, $this->label_count['singular'], $this->label_count['plural'], [], $options);
   }
 
   /**
@@ -810,7 +844,6 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
     return $this->group;
   }
 
-
   /**
    * {@inheritdoc}
    */
@@ -879,7 +912,7 @@ class EntityType extends PluginDefinition implements EntityTypeInterface {
     // If this entity type uses entities to manage its bundles then depend on
     // the bundle entity.
     if ($bundle_entity_type_id = $this->getBundleEntityType()) {
-      if (!$bundle_entity = \Drupal::entityManager()->getStorage($bundle_entity_type_id)->load($bundle)) {
+      if (!$bundle_entity = \Drupal::entityTypeManager()->getStorage($bundle_entity_type_id)->load($bundle)) {
         throw new \LogicException(sprintf('Missing bundle entity, entity type %s, entity id %s.', $bundle_entity_type_id, $bundle));
       }
       $config_dependency = [
