@@ -1251,29 +1251,13 @@ function hook_page_bottom(array &$page_bottom) {
 function hook_theme($existing, $type, $theme, $path) {
   return [
     'my_module_display' => [
-      'variables' => [
-        'my_modules' => NULL,
-        'topics' => NULL,
-        'parents' => NULL,
-        'tid' => NULL,
-        'sortby' => NULL,
-        'my_module_per_page' => NULL,
-      ],
+      'variables' => ['my_modules' => NULL, 'topics' => NULL, 'parents' => NULL, 'tid' => NULL, 'sortby' => NULL, 'my_module_per_page' => NULL],
     ],
     'my_module_list' => [
-      'variables' => [
-        'my_modules' => NULL,
-        'parents' => NULL,
-        'tid' => NULL,
-      ],
+      'variables' => ['my_modules' => NULL, 'parents' => NULL, 'tid' => NULL],
     ],
     'my_module_icon' => [
-      'variables' => [
-        'new_posts' => NULL,
-        'num_posts' => 0,
-        'comment_mode' => 0,
-        'sticky' => 0,
-      ],
+      'variables' => ['new_posts' => NULL, 'num_posts' => 0, 'comment_mode' => 0, 'sticky' => 0],
     ],
     'status_report' => [
       'render element' => 'requirements',
