@@ -765,29 +765,6 @@ class Url implements TrustedCallbackInterface {
     return $this->urlGenerator()->generateFromRoute($this->getRouteName(), $this->getRouteParameters(), $this->getOptions(), $collect_bubbleable_metadata);
   }
 
-  /**
-   * Returns the route information for a render array.
-   *
-   * @return array
-   *   An associative array suitable for a render array.
-   *
-   * @deprecated in drupal:10.1.0 and is removed from drupal:11.0.0. There is no
-   *   replacement.
-   *
-   * @see https://www.drupal.org/node/3342977
-   */
-  public function toRenderArray() {
-    @trigger_error(__METHOD__ . '() is deprecated in drupal:10.1.0 and is removed from drupal:11.0.0. There is no replacement. See https://www.drupal.org/node/3342977', E_USER_DEPRECATED);
-    $render_array = [
-      '#url' => $this,
-      '#options' => $this->getOptions(),
-    ];
-    if (!$this->unrouted) {
-      $render_array['#access_callback'] = [self::class, 'renderAccess'];
-    }
-    return $render_array;
-  }
-
   /**
    * Returns the internal path (system path) for this route.
    *
@@ -834,25 +811,6 @@ class Url implements TrustedCallbackInterface {
     return $return_as_object ? AccessResult::allowed() : TRUE;
   }
 
-  /**
-   * Checks a URL render element against applicable access check services.
-   *
-   * @param array $element
-   *   A render element as returned from \Drupal\Core\Url::toRenderArray().
-   *
-   * @return bool
-   *   Returns TRUE if the current user has access to the URL, otherwise FALSE.
-   *
-   * @deprecated in drupal:10.1.0 and is removed from drupal:11.0.0. There is no
-   *   replacement.
-   *
-   * @see https://www.drupal.org/node/3342977
-   */
-  public static function renderAccess(array $element) {
-    @trigger_error(__METHOD__ . '() is deprecated in drupal:10.1.0 and is removed from drupal:11.0.0. There is no replacement. See https://www.drupal.org/node/3342977', E_USER_DEPRECATED);
-    return $element['#url']->access();
-  }
-
   /**
    * @return \Drupal\Core\Access\AccessManagerInterface
    */
@@ -920,8 +878,7 @@ class Url implements TrustedCallbackInterface {
    * {@inheritdoc}
    */
   public static function trustedCallbacks() {
-    // @todo Clean-up in https://www.drupal.org/i/3343153
-    return ['renderAccess'];
+    return [];
   }
 
 }
