@@ -921,10 +921,6 @@
 
 				return (doc && doc.documentElement && doc.documentElement.nodeName !== 'parsererror') ? doc : null;
 			};
-			var parseJSON = $.parseJSON || function(s) {
-				/* jslint evil:true */
-				return window['eval']('(' + s + ')');			// eslint-disable-line dot-notation
-			};
 
 			var httpData = function(xhr, type, s) { // mostly lifted from jq1.4.4
 
@@ -942,7 +938,7 @@
 				}
 				if (typeof data === 'string') {
 					if ((type === 'json' || !type) && ct.indexOf('json') >= 0) {
-						data = parseJSON(data);
+						data = JSON.parse(data);
 					} else if ((type === 'script' || !type) && ct.indexOf('javascript') >= 0) {
 						$.globalEval(data);
 					}
@@ -1262,7 +1258,7 @@
 	 *	v === ['C1']
 	 *
 	 * The successful argument controls whether or not the field element must be 'successful'
-	 * (per https://www.w3.org/TR/html4/interact/forms.html#successful-controls).
+	 * (per http://www.w3.org/TR/html4/interact/forms.html#successful-controls).
 	 * The default value of the successful argument is true. If this value is false the value(s)
 	 * for each element is returned.
 	 *
