@@ -4,7 +4,6 @@ declare(strict_types = 1);
 
 namespace Drupal\ckeditor5\Plugin\Editor;
 
-use Drupal\ckeditor5\CKEditor5StylesheetsMessage;
 use Drupal\ckeditor5\HTMLRestrictions;
 use Drupal\ckeditor5\Plugin\CKEditor5Plugin\Heading;
 use Drupal\ckeditor5\Plugin\CKEditor5PluginDefinition;
@@ -99,13 +98,6 @@ class CKEditor5 extends EditorBase implements ContainerFactoryPluginInterface {
    */
   protected $cache;
 
-  /**
-   * The ckeditor_stylesheets message utility.
-   *
-   * @var \Drupal\ckeditor5\CKEditor5StylesheetsMessage
-   */
-  private $stylesheetsMessage;
-
   /**
    * A logger instance.
    *
@@ -132,19 +124,16 @@ class CKEditor5 extends EditorBase implements ContainerFactoryPluginInterface {
    *   The smart default settings utility.
    * @param \Drupal\Core\Cache\CacheBackendInterface $cache
    *   The cache.
-   * @param \Drupal\ckeditor5\CKEditor5StylesheetsMessage $stylesheets_message
-   *   The ckeditor_stylesheets message utility.
    * @param \Psr\Log\LoggerInterface $logger
    *   A logger instance.
    */
-  public function __construct(array $configuration, $plugin_id, $plugin_definition, CKEditor5PluginManagerInterface $ckeditor5_plugin_manager, LanguageManagerInterface $language_manager, ModuleHandlerInterface $module_handler, SmartDefaultSettings $smart_default_settings, CacheBackendInterface $cache, CKEditor5StylesheetsMessage $stylesheets_message, LoggerInterface $logger) {
+  public function __construct(array $configuration, $plugin_id, $plugin_definition, CKEditor5PluginManagerInterface $ckeditor5_plugin_manager, LanguageManagerInterface $language_manager, ModuleHandlerInterface $module_handler, SmartDefaultSettings $smart_default_settings, CacheBackendInterface $cache, LoggerInterface $logger) {
     parent::__construct($configuration, $plugin_id, $plugin_definition);
     $this->ckeditor5PluginManager = $ckeditor5_plugin_manager;
     $this->languageManager = $language_manager;
     $this->moduleHandler = $module_handler;
     $this->smartDefaultSettings = $smart_default_settings;
     $this->cache = $cache;
-    $this->stylesheetsMessage = $stylesheets_message;
     $this->logger = $logger;
   }
 
@@ -161,7 +150,6 @@ class CKEditor5 extends EditorBase implements ContainerFactoryPluginInterface {
       $container->get('module_handler'),
       $container->get('ckeditor5.smart_default_settings'),
       $container->get('cache.default'),
-      $container->get('ckeditor5.stylesheets.message'),
       $container->get('logger.channel.ckeditor5')
     );
   }
@@ -298,23 +286,6 @@ class CKEditor5 extends EditorBase implements ContainerFactoryPluginInterface {
       $form_state->set('editor', $editor);
     }
 
-    if ($css_warning = $this->stylesheetsMessage->getWarning()) {
-      // Explicitly render this single warning message visually close to the
-      // text editor since this is a very long form. Otherwise, it may be
-      // interpreted as a text format problem, or ignored entirely.
-      // All other messages will be rendered in the default location.
-      // @see \Drupal\Core\Render\Element\StatusMessages
-      $form['css_warning'] = [
-        '#theme' => 'status_messages',
-        '#message_list' => [
-          'warning' => [$css_warning],
-        ],
-        '#status_headings' => [
-          'warning' => $this->t('Warning message'),
-        ],
-      ];
-    }
-
     // AJAX validation errors should appear visually close to the text editor
     // since this is a very long form: otherwise they would not be noticed.
     $form['real_time_validation_errors_location'] = [
@@ -955,8 +926,6 @@ class CKEditor5 extends EditorBase implements ContainerFactoryPluginInterface {
       ],
     ] + $plugin_config;
 
-    $settings['config']['licenseKey'] ??= 'GPL';
-
     if ($this->moduleHandler->moduleExists('locale')) {
       $language_interface = $this->languageManager->getCurrentLanguage();
       $settings['language']['ui'] = _ckeditor5_get_langcode_mapping($language_interface->getId());
