@@ -120,7 +120,7 @@ class HttpExceptionNormalizer extends NormalizerBase {
    */
   public static function getInfoUrl($status_code) {
     // Depending on the error code we'll return a different URL.
-    $url = 'https://www.w3.org/Protocols/rfc2616/rfc2616-sec10.html';
+    $url = 'http://www.w3.org/Protocols/rfc2616/rfc2616-sec10.html';
     $sections = [
       '100' => '#sec10.1.1',
       '101' => '#sec10.1.2',
@@ -166,15 +166,6 @@ class HttpExceptionNormalizer extends NormalizerBase {
     return empty($sections[$status_code]) ? NULL : $url . $sections[$status_code];
   }
 
-  /**
-   * {@inheritdoc}
-   */
-  public function hasCacheableSupportsMethod(): bool {
-    @trigger_error(__METHOD__ . '() is deprecated in drupal:10.1.0 and is removed from drupal:11.0.0. Use getSupportedTypes() instead. See https://www.drupal.org/node/3359695', E_USER_DEPRECATED);
-
-    return TRUE;
-  }
-
   /**
    * {@inheritdoc}
    */
