@@ -1,11 +1,15 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\layout_builder\FunctionalJavascript;
 
 use Drupal\block_content\Entity\BlockContentType;
 use Drupal\FunctionalJavascriptTests\WebDriverTestBase;
 use Drupal\Tests\contextual\FunctionalJavascript\ContextualLinkClickTrait;
 
+// cspell:ignore fieldbody
+
 /**
  * Tests the Layout Builder UI.
  *
@@ -22,9 +26,13 @@ class LayoutBuilderUiTest extends WebDriverTestBase {
    */
   const FIELD_UI_PREFIX = 'admin/structure/types/manage/bundle_with_section_field';
 
-  public static $modules = [
+  /**
+   * {@inheritdoc}
+   */
+  protected static $modules = [
     'layout_builder',
     'block',
+    'field_ui',
     'node',
     'block_content',
     'contextual',
@@ -34,7 +42,12 @@ class LayoutBuilderUiTest extends WebDriverTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected $defaultTheme = 'starterkit_theme';
+
+  /**
+   * {@inheritdoc}
+   */
+  protected function setUp(): void {
     parent::setUp();
 
     $this->createContentType(['type' => 'bundle_with_section_field']);
@@ -48,48 +61,52 @@ class LayoutBuilderUiTest extends WebDriverTestBase {
     ]));
 
     // Enable layout builder.
-    $this->drupalPostForm(
-      static::FIELD_UI_PREFIX . '/display/default',
-      ['layout[enabled]' => TRUE],
-      'Save'
-    );
+    $this->drupalGet(static::FIELD_UI_PREFIX . '/display/default');
+    $this->submitForm(['layout[enabled]' => TRUE], 'Save');
   }
 
   /**
    * Tests that after removing sections reloading the page does not re-add them.
    */
-  public function testReloadWithNoSections() {
+  public function testReloadWithNoSections(): void {
     $assert_session = $this->assertSession();
     $page = $this->getSession()->getPage();
 
     // Remove all of the sections from the page.
     $this->drupalGet(static::FIELD_UI_PREFIX . '/display/default/layout');
-    $page->clickLink('Remove section');
+    $page->clickLink('Remove Section 1');
     $assert_session->assertWaitOnAjaxRequest();
     $page->pressButton('Remove');
     $assert_session->assertWaitOnAjaxRequest();
     // Assert that there are no sections on the page.
-    $assert_session->pageTextNotContains('Remove section');
-    $assert_session->pageTextNotContains('Add Block');
+    $assert_session->pageTextNotContains('Remove Section 1');
+    $assert_session->pageTextNotContains('Add block');
 
     // Reload the page.
     $this->drupalGet(static::FIELD_UI_PREFIX . '/display/default/layout');
     // Assert that there are no sections on the page.
-    $assert_session->pageTextNotContains('Remove section');
-    $assert_session->pageTextNotContains('Add Block');
+    $assert_session->pageTextNotContains('Remove Section 1');
+    $assert_session->pageTextNotContains('Add block');
   }
 
   /**
    * Tests the message indicating unsaved changes.
    */
-  public function testUnsavedChangesMessage() {
+  public function testUnsavedChangesMessage(): void {
     $assert_session = $this->assertSession();
     $page = $this->getSession()->getPage();
 
-    // Make and then discard changes.
     $this->assertModifiedLayout(static::FIELD_UI_PREFIX . '/display/default/layout');
+    // Discard then cancel.
+    $page->pressButton('Discard changes');
+    $page->clickLink('Cancel');
+    $assert_session->addressEquals(static::FIELD_UI_PREFIX . '/display/default/layout');
+    $assert_session->pageTextContainsOnce('You have unsaved changes.');
+
+    // Discard then confirm.
     $page->pressButton('Discard changes');
     $page->pressButton('Confirm');
+    $assert_session->addressEquals(static::FIELD_UI_PREFIX . '/display/default');
     $assert_session->pageTextNotContains('You have unsaved changes.');
 
     // Make and then save changes.
@@ -103,16 +120,20 @@ class LayoutBuilderUiTest extends WebDriverTestBase {
    *
    * @param string $path
    *   The path to a Layout Builder UI page.
+   *
+   * @internal
    */
-  protected function assertModifiedLayout($path) {
+  protected function assertModifiedLayout(string $path): void {
     $assert_session = $this->assertSession();
     $page = $this->getSession()->getPage();
 
     $this->drupalGet($path);
-    $page->clickLink('Add Section');
-    $assert_session->assertWaitOnAjaxRequest();
+    $page->clickLink('Add section');
+    $assert_session->waitForElementVisible('named', ['link', 'One column']);
     $assert_session->pageTextNotContains('You have unsaved changes.');
     $page->clickLink('One column');
+    $assert_session->waitForElementVisible('named', ['button', 'Add section']);
+    $page->pressButton('Add section');
     $assert_session->assertWaitOnAjaxRequest();
     $assert_session->pageTextContainsOnce('You have unsaved changes.');
 
@@ -124,7 +145,7 @@ class LayoutBuilderUiTest extends WebDriverTestBase {
   /**
    * Tests that elements that open the dialog are properly highlighted.
    */
-  public function testAddHighlights() {
+  public function testAddHighlights(): void {
     $assert_session = $this->assertSession();
     $page = $this->getSession()->getPage();
 
@@ -139,7 +160,7 @@ class LayoutBuilderUiTest extends WebDriverTestBase {
     $this->drupalGet(static::FIELD_UI_PREFIX . '/display/default/layout');
     $assert_session->elementsCount('css', '.layout-builder__add-section', 2);
     $assert_session->elementNotExists('css', '.is-layout-builder-highlighted');
-    $page->clickLink('Add Section');
+    $page->clickLink('Add section');
     $this->assertNotEmpty($assert_session->waitForElement('css', '#drupal-off-canvas .item-list'));
     $assert_session->assertWaitOnAjaxRequest();
 
@@ -160,15 +181,15 @@ class LayoutBuilderUiTest extends WebDriverTestBase {
     $this->assertNotEmpty($assert_session->waitForElementVisible('css', '[data-layout-delta="1"]'));
     $assert_session->elementsCount('css', '.layout-builder__add-block', 3);
 
-    // Add a custom block.
-    $page->clickLink('Add Block');
-    $this->assertNotEmpty($assert_session->waitForElementVisible('css', 'a:contains("Create custom block")'));
+    // Add a content block.
+    $page->clickLink('Add block');
+    $this->assertNotEmpty($assert_session->waitForElementVisible('css', 'a:contains("Create content block")'));
     $assert_session->assertWaitOnAjaxRequest();
 
     // Highlight is present with ChooseBlockController::build().
     $this->assertHighlightedElement('[data-layout-builder-highlight-id="block-0-first"]');
-    $page->clickLink('Create custom block');
-    $this->assertNotEmpty($assert_session->waitForElementVisible('css', '#drupal-off-canvas input[value="Add Block"]'));
+    $page->clickLink('Create content block');
+    $this->assertNotEmpty($assert_session->waitForElementVisible('css', '#drupal-off-canvas input[value="Add block"]'));
     $assert_session->assertWaitOnAjaxRequest();
 
     // Highlight is present with ChooseBlockController::inlineBlockList().
@@ -177,12 +198,12 @@ class LayoutBuilderUiTest extends WebDriverTestBase {
     $this->assertHighlightNotExists();
 
     // The highlight should persist with all block config dialogs.
-    $page->clickLink('Add Block');
+    $page->clickLink('Add block');
     $this->assertNotEmpty($assert_session->waitForElementVisible('css', 'a:contains("Recent content")'));
     $assert_session->assertWaitOnAjaxRequest();
     $this->assertHighlightedElement('[data-layout-builder-highlight-id="block-0-first"]');
     $page->clickLink('Recent content');
-    $this->assertNotEmpty($assert_session->waitForElementVisible('css', '#drupal-off-canvas input[value="Add Block"]'));
+    $this->assertNotEmpty($assert_session->waitForElementVisible('css', '#drupal-off-canvas input[value="Add block"]'));
 
     // The highlight is present with ConfigureBlockFormBase::doBuildForm().
     $this->assertHighlightedElement('[data-layout-builder-highlight-id="block-0-first"]');
@@ -190,14 +211,14 @@ class LayoutBuilderUiTest extends WebDriverTestBase {
     $this->assertHighlightNotExists();
 
     // The highlight is present when the "Configure section" dialog is open.
-    $page->clickLink('Configure section');
+    $page->clickLink('Configure Section 1');
     $this->assertNotEmpty($assert_session->waitForElementVisible('css', '#drupal-off-canvas'));
     $this->assertHighlightedElement('[data-layout-builder-highlight-id="section-update-0"]');
     $page->pressButton('Close');
     $this->assertHighlightNotExists();
 
-    // The highlight is present when the "Remove section" dialog is open.
-    $page->clickLink('Remove section');
+    // The highlight is present when the "Remove Section" dialog is open.
+    $page->clickLink('Remove Section 1');
     $this->assertNotEmpty($assert_session->waitForElementVisible('css', '#drupal-off-canvas'));
     $assert_session->assertWaitOnAjaxRequest();
     $this->assertHighlightedElement('[data-layout-builder-highlight-id="section-update-0"]');
@@ -233,13 +254,37 @@ class LayoutBuilderUiTest extends WebDriverTestBase {
     $this->assertHighlightNotExists();
   }
 
+  /**
+   * Tests removing newly added extra field.
+   */
+  public function testNewExtraField(): void {
+    $assert_session = $this->assertSession();
+    $page = $this->getSession()->getPage();
+
+    // At this point layout builder has been enabled for the test content type.
+    // Install a test module that creates a new extra field then clear cache.
+    \Drupal::service('module_installer')->install(['layout_builder_extra_field_test']);
+    \Drupal::service('entity_field.manager')->clearCachedFieldDefinitions();
+
+    // View the layout and try to remove the new extra field.
+    $this->drupalGet(static::FIELD_UI_PREFIX . '/display/default/layout');
+    $assert_session->pageTextContains('New Extra Field');
+    $this->clickContextualLink('.block-extra-field-blocknodebundle-with-section-fieldlayout-builder-extra-field-test', 'Remove block');
+    $this->assertNotEmpty($assert_session->waitForElementVisible('css', '#drupal-off-canvas'));
+    $assert_session->assertWaitOnAjaxRequest();
+    $assert_session->pageTextContains('Are you sure you want to remove');
+    $page->pressButton('Remove');
+    $assert_session->assertWaitOnAjaxRequest();
+    $assert_session->pageTextNotContains('New Extra Field');
+  }
+
   /**
    * Confirms the presence of the 'is-layout-builder-highlighted' class.
    *
    * @param string $selector
    *   The highlighted element must also match this selector.
    */
-  private function assertHighlightedElement($selector) {
+  private function assertHighlightedElement(string $selector): void {
     $assert_session = $this->assertSession();
     $page = $this->getSession()->getPage();
 
@@ -253,7 +298,8 @@ class LayoutBuilderUiTest extends WebDriverTestBase {
   /**
    * Waits for the dialog to close and confirms no highlights are present.
    */
-  private function assertHighlightNotExists() {
+  private function assertHighlightNotExists(): void {
+    $this->markTestSkipped("Skipped temporarily for random fails.");
     $assert_session = $this->assertSession();
 
     $assert_session->assertNoElementAfterWait('css', '#drupal-off-canvas');
