@@ -194,18 +194,6 @@ class Migration extends PluginBase implements MigrationInterface, RequirementsIn
    */
   protected $sourceRowStatus = MigrateIdMapInterface::STATUS_IMPORTED;
 
-  /**
-   * Track time of last import if TRUE.
-   *
-   * @var bool
-   *
-   * @deprecated in drupal:10.1.0 and is removed from drupal:11.0.0. There is no
-   * replacement.
-   *
-   * @see https://www.drupal.org/node/3282894
-   */
-  protected $trackLastImported = FALSE;
-
   /**
    * These migrations must be already executed before this migration can run.
    *
@@ -336,13 +324,9 @@ class Migration extends PluginBase implements MigrationInterface, RequirementsIn
       $this->$key = $value;
     }
 
-    if (isset($plugin_definition['trackLastImported'])) {
-      @trigger_error("The key 'trackLastImported' is deprecated in drupal:10.1.0 and is removed from drupal:11.0.0. There is no replacement. See https://www.drupal.org/node/3282894", E_USER_DEPRECATED);
-    }
-
     $this->migration_dependencies = ($this->migration_dependencies ?: []) + ['required' => [], 'optional' => []];
     if (count($this->migration_dependencies) !== 2 || !is_array($this->migration_dependencies['required']) || !is_array($this->migration_dependencies['optional'])) {
-      @trigger_error("Invalid migration dependencies for {$this->id()} is deprecated in drupal:10.1.0 and will cause an error in drupal:11.0.0. See https://www.drupal.org/node/3266691", E_USER_DEPRECATED);
+      throw new InvalidPluginDefinitionException($this->id(), "Invalid migration dependencies configuration for migration {$this->id()}");
     }
   }
 
@@ -608,9 +592,6 @@ class Migration extends PluginBase implements MigrationInterface, RequirementsIn
     }
     elseif ($property_name === 'migration_dependencies') {
       $value = ($value ?: []) + ['required' => [], 'optional' => []];
-      if (count($value) !== 2 || !is_array($value['required']) || !is_array($value['optional'])) {
-        @trigger_error("Invalid migration dependencies for {$this->id()} is deprecated in drupal:10.1.0 and will cause an error in drupal:11.0.0. See https://www.drupal.org/node/3266691", E_USER_DEPRECATED);
-      }
     }
     $this->{$property_name} = $value;
     return $this;
@@ -656,47 +637,23 @@ class Migration extends PluginBase implements MigrationInterface, RequirementsIn
     return $this;
   }
 
-  /**
-   * {@inheritdoc}
-   */
-  public function isTrackLastImported() {
-    @trigger_error(__METHOD__ . '() is deprecated in drupal:10.1.0 and is removed from drupal:11.0.0. There is no replacement. See https://www.drupal.org/node/3282894', E_USER_DEPRECATED);
-    return $this->trackLastImported;
-  }
-
-  /**
-   * {@inheritdoc}
-   */
-  public function setTrackLastImported($track_last_imported) {
-    @trigger_error(__METHOD__ . '() is deprecated in drupal:10.1.0 and is removed from drupal:11.0.0. There is no replacement. See https://www.drupal.org/node/3282894', E_USER_DEPRECATED);
-    $this->trackLastImported = (bool) $track_last_imported;
-    return $this;
-  }
-
   /**
    * Get the dependencies for this migration.
    *
-   * @param bool $expand
-   *   Will issue a deprecation in Drupal 10 if set to FALSE. See
-   *   https://www.drupal.org/node/3266691.
-   *
    * @return array
-   *   The dependencies for this migrations.
+   *   The dependencies for this migration.
    */
-  public function getMigrationDependencies(bool $expand = FALSE) {
-    if (!$expand) {
-      @trigger_error('Calling Migration::getMigrationDependencies() without expanding the plugin IDs is deprecated in drupal:10.1.0 and is removed from drupal:11.0.0. In most cases, use getMigrationDependencies(TRUE). See https://www.drupal.org/node/3266691', E_USER_DEPRECATED);
+  public function getMigrationDependencies() {
+    if (func_num_args() > 0) {
+      @trigger_error('Calling ' . __METHOD__ . ' with the $expand parameter is deprecated in drupal:11.0.0 and is removed drupal:12.0.0. See https://www.drupal.org/node/3442785', E_USER_DEPRECATED);
     }
-    // @todo Before Drupal 11.0.0, remove ::set() and these checks.
-    // @see https://www.drupal.org/project/drupal/issues/3262395
+
     $this->migration_dependencies = ($this->migration_dependencies ?: []) + ['required' => [], 'optional' => []];
     if (count($this->migration_dependencies) !== 2 || !is_array($this->migration_dependencies['required']) || !is_array($this->migration_dependencies['optional'])) {
       throw new InvalidPluginDefinitionException($this->id(), "Invalid migration dependencies configuration for migration {$this->id()}");
     }
     $this->migration_dependencies['optional'] = array_unique(array_merge($this->migration_dependencies['optional'], $this->findMigrationDependencies($this->process)));
-    if (!$expand) {
-      return $this->migration_dependencies;
-    }
+
     return array_map(
       [$this->migrationPluginManager, 'expandPluginIds'],
       $this->migration_dependencies
@@ -763,14 +720,6 @@ class Migration extends PluginBase implements MigrationInterface, RequirementsIn
     return $this->source;
   }
 
-  /**
-   * {@inheritdoc}
-   */
-  public function getTrackLastImported() {
-    @trigger_error(__METHOD__ . '() is deprecated in drupal:10.1.0 and is removed from drupal:11.0.0. There is no replacement. See https://www.drupal.org/node/3282894', E_USER_DEPRECATED);
-    return $this->trackLastImported;
-  }
-
   /**
    * {@inheritdoc}
    */
