@@ -30,8 +30,6 @@ class MigrationPluginListTest extends KernelTestBase {
     'ban',
     'block',
     'block_content',
-    // @todo Remove book in https://www.drupal.org/project/drupal/issues/3376101
-    'book',
     'comment',
     'contact',
     'content_translation',
@@ -39,8 +37,6 @@ class MigrationPluginListTest extends KernelTestBase {
     'field',
     'file',
     'filter',
-    // @todo Remove forum in https://www.drupal.org/project/drupal/issues/3261653
-    'forum',
     'image',
     'language',
     'locale',
@@ -51,14 +47,10 @@ class MigrationPluginListTest extends KernelTestBase {
     'path',
     'search',
     'shortcut',
-    // @todo Remove statistics in https://www.drupal.org/project/drupal/issues/3341092
-    'statistics',
     'syslog',
     'system',
     'taxonomy',
     'text',
-    // @todo Remove tracker in https://www.drupal.org/project/drupal/issues/3261452
-    'tracker',
     'update',
     'user',
   ];
