@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\node\Functional;
 
 use Drupal\Core\Entity\EntityInterface;
@@ -43,17 +45,6 @@ class NodeCacheTagsTest extends EntityWithUriCacheTagsTestBase {
     return $node;
   }
 
-  /**
-   * {@inheritdoc}
-   */
-  protected function getDefaultCacheContexts() {
-    $defaults = parent::getDefaultCacheContexts();
-    // @see \Drupal\node\Controller\NodeViewController::view()
-    $defaults[] = 'url.site';
-    $defaults[] = 'user.roles:anonymous';
-    return $defaults;
-  }
-
   /**
    * {@inheritdoc}
    */
