@@ -1,23 +1,25 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\path\Functional;
 
 use Drupal\Core\Cache\Cache;
 use Drupal\Core\Database\Database;
 use Drupal\Core\Url;
+use Drupal\Tests\WaitTerminateTestTrait;
 
 /**
- * Add, edit, delete, and change alias and verify its consistency in the
- * database.
+ * Tests modifying path aliases from the UI.
  *
  * @group path
  */
 class PathAliasTest extends PathTestBase {
 
+  use WaitTerminateTestTrait;
+
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = ['path'];
 
@@ -26,6 +28,9 @@ class PathAliasTest extends PathTestBase {
    */
   protected $defaultTheme = 'stark';
 
+  /**
+   * {@inheritdoc}
+   */
   protected function setUp(): void {
     parent::setUp();
 
@@ -38,12 +43,17 @@ class PathAliasTest extends PathTestBase {
       'access content overview',
     ]);
     $this->drupalLogin($web_user);
+
+    // The \Drupal\path_alias\AliasWhitelist service performs cache clears after
+    // Drupal has flushed the response to the client. We use
+    // WaitTerminateTestTrait to wait for Drupal to do this before continuing.
+    $this->setWaitForTerminate();
   }
 
   /**
    * Tests the path cache.
    */
-  public function testPathCache() {
+  public function testPathCache(): void {
     // Create test node.
     $node1 = $this->drupalCreateNode();
 
@@ -51,7 +61,8 @@ class PathAliasTest extends PathTestBase {
     $edit = [];
     $edit['path[0][value]'] = '/node/' . $node1->id();
     $edit['alias[0][value]'] = '/' . $this->randomMachineName(8);
-    $this->drupalPostForm('admin/config/search/path/add', $edit, t('Save'));
+    $this->drupalGet('admin/config/search/path/add');
+    $this->submitForm($edit, 'Save');
 
     // Check the path alias whitelist cache.
     $whitelist = \Drupal::cache('bootstrap')->get('path_alias_whitelist');
@@ -76,7 +87,7 @@ class PathAliasTest extends PathTestBase {
   /**
    * Tests alias functionality through the admin interfaces.
    */
-  public function testAdminAlias() {
+  public function testAdminAlias(): void {
     // Create test node.
     $node1 = $this->drupalCreateNode();
 
@@ -84,19 +95,22 @@ class PathAliasTest extends PathTestBase {
     $edit = [];
     $edit['path[0][value]'] = '/node/' . $node1->id();
     $edit['alias[0][value]'] = '/' . $this->getRandomGenerator()->word(8);
-    $this->drupalPostForm('admin/config/search/path/add', $edit, t('Save'));
+    $this->drupalGet('admin/config/search/path/add');
+    $this->submitForm($edit, 'Save');
 
     // Confirm that the alias works.
     $this->drupalGet($edit['alias[0][value]']);
-    $this->assertText($node1->label(), 'Alias works.');
+    $this->assertSession()->pageTextContains($node1->label());
     $this->assertSession()->statusCodeEquals(200);
     // Confirm that the alias works in a case-insensitive way.
     $this->assertTrue(ctype_lower(ltrim($edit['alias[0][value]'], '/')));
     $this->drupalGet($edit['alias[0][value]']);
-    $this->assertText($node1->label(), 'Alias works lower case.');
+    // Lower case.
+    $this->assertSession()->pageTextContains($node1->label());
     $this->assertSession()->statusCodeEquals(200);
     $this->drupalGet(mb_strtoupper($edit['alias[0][value]']));
-    $this->assertText($node1->label(), 'Alias works upper case.');
+    // Upper case.
+    $this->assertSession()->pageTextContains($node1->label());
     $this->assertSession()->statusCodeEquals(200);
 
     // Change alias to one containing "exotic" characters.
@@ -117,19 +131,21 @@ class PathAliasTest extends PathTestBase {
       // currently unable to find the upper-case versions of non-ASCII
       // characters.
       // @todo fix this in https://www.drupal.org/node/2607432
+      // cSpell:disable-next-line
       $edit['alias[0][value]'] .= "ïвβéø";
     }
-    $this->drupalPostForm('admin/config/search/path/edit/' . $pid, $edit, t('Save'));
+    $this->drupalGet('admin/config/search/path/edit/' . $pid);
+    $this->submitForm($edit, 'Save');
 
     // Confirm that the alias works.
     $this->drupalGet(mb_strtoupper($edit['alias[0][value]']));
-    $this->assertText($node1->label(), 'Changed alias works.');
+    $this->assertSession()->pageTextContains($node1->label());
     $this->assertSession()->statusCodeEquals(200);
 
     $this->container->get('path_alias.manager')->cacheClear();
     // Confirm that previous alias no longer works.
     $this->drupalGet($previous);
-    $this->assertNoText($node1->label(), 'Previous alias no longer works.');
+    $this->assertSession()->pageTextNotContains($node1->label());
     $this->assertSession()->statusCodeEquals(404);
 
     // Create second test node.
@@ -137,29 +153,28 @@ class PathAliasTest extends PathTestBase {
 
     // Set alias to second test node.
     $edit['path[0][value]'] = '/node/' . $node2->id();
-    // leave $edit['alias'] the same
-    $this->drupalPostForm('admin/config/search/path/add', $edit, t('Save'));
+    // Leave $edit['alias'] the same
+    $this->drupalGet('admin/config/search/path/add');
+    $this->submitForm($edit, 'Save');
 
     // Confirm no duplicate was created.
-    $this->assertRaw(t('The alias %alias is already in use in this language.', ['%alias' => $edit['alias[0][value]']]), 'Attempt to move alias was rejected.');
+    $this->assertSession()->statusMessageContains("The alias {$edit['alias[0][value]']} is already in use in this language.", 'error');
 
     $edit_upper = $edit;
     $edit_upper['alias[0][value]'] = mb_strtoupper($edit['alias[0][value]']);
-    $this->drupalPostForm('admin/config/search/path/add', $edit_upper, t('Save'));
-    $this->assertRaw(t('The alias %alias could not be added because it is already in use in this language with different capitalization: %stored_alias.', [
-      '%alias' => $edit_upper['alias[0][value]'],
-      '%stored_alias' => $edit['alias[0][value]'],
-    ]), 'Attempt to move upper-case alias was rejected.');
+    $this->drupalGet('admin/config/search/path/add');
+    $this->submitForm($edit_upper, 'Save');
+    $this->assertSession()->statusMessageContains("The alias {$edit_upper['alias[0][value]']} could not be added because it is already in use in this language with different capitalization: {$edit['alias[0][value]']}.", 'error');
 
     // Delete alias.
     $this->drupalGet('admin/config/search/path/edit/' . $pid);
-    $this->clickLink(t('Delete'));
-    $this->assertRaw(t('Are you sure you want to delete the URL alias %name?', ['%name' => $edit['alias[0][value]']]));
-    $this->drupalPostForm(NULL, [], t('Delete'));
+    $this->clickLink('Delete');
+    $this->assertSession()->pageTextContains("Are you sure you want to delete the URL alias {$edit['alias[0][value]']}?");
+    $this->submitForm([], 'Delete');
 
     // Confirm that the alias no longer works.
     $this->drupalGet($edit['alias[0][value]']);
-    $this->assertNoText($node1->label(), 'Alias was successfully deleted.');
+    $this->assertSession()->pageTextNotContains($node1->label());
     $this->assertSession()->statusCodeEquals(404);
 
     // Create a really long alias.
@@ -167,12 +182,10 @@ class PathAliasTest extends PathTestBase {
     $edit['path[0][value]'] = '/node/' . $node1->id();
     $alias = '/' . $this->randomMachineName(128);
     $edit['alias[0][value]'] = $alias;
-    // The alias is shortened to 50 characters counting the ellipsis.
-    $truncated_alias = substr($alias, 0, 47);
-    $this->drupalPostForm('admin/config/search/path/add', $edit, t('Save'));
-    $this->assertNoText($alias, 'The untruncated alias was not found.');
-    // The 'truncated' alias will always be found.
-    $this->assertText($truncated_alias, 'The truncated alias was found.');
+    $this->drupalGet('admin/config/search/path/add');
+    $this->submitForm($edit, 'Save');
+    // The alias will always be found.
+    $this->assertSession()->pageTextContains($alias);
 
     // Create third test node.
     $node3 = $this->drupalCreateNode();
@@ -182,7 +195,8 @@ class PathAliasTest extends PathTestBase {
     $edit['path[0][value]'] = '/node/' . $node3->id();
     $node3_alias = '/' . $this->randomMachineName(8);
     $edit['alias[0][value]'] = $node3_alias;
-    $this->drupalPostForm('admin/config/search/path/add', $edit, t('Save'));
+    $this->drupalGet('admin/config/search/path/add');
+    $this->submitForm($edit, 'Save');
 
     // Create fourth test node.
     $node4 = $this->drupalCreateNode();
@@ -192,23 +206,27 @@ class PathAliasTest extends PathTestBase {
     $edit['path[0][value]'] = '/node/' . $node4->id();
     $node4_alias = '/' . $this->randomMachineName(8);
     $edit['alias[0][value]'] = $node4_alias . '/';
-    $this->drupalPostForm('admin/config/search/path/add', $edit, t('Save'));
+    $this->drupalGet('admin/config/search/path/add');
+    $this->submitForm($edit, 'Save');
 
     // Confirm that the alias with trailing slash is not found.
-    $this->assertNoText($edit['alias[0][value]'], 'The absolute alias was not found.');
+    $this->assertSession()->pageTextNotContains($edit['alias[0][value]']);
     // The alias without trailing flash is found.
-    $this->assertText(trim($edit['alias[0][value]'], '/'), 'The alias without trailing slash was found.');
+    $this->assertSession()->pageTextContains(trim($edit['alias[0][value]'], '/'));
 
     // Update an existing alias to point to a different source.
     $pid = $this->getPID($node4_alias);
     $edit = [];
     $edit['alias[0][value]'] = $node4_alias;
     $edit['path[0][value]'] = '/node/' . $node2->id();
-    $this->drupalPostForm('admin/config/search/path/edit/' . $pid, $edit, t('Save'));
-    $this->assertText('The alias has been saved.');
+    $this->drupalGet('admin/config/search/path/edit/' . $pid);
+    $this->submitForm($edit, 'Save');
+    $this->assertSession()->statusMessageContains('The alias has been saved.', 'status');
     $this->drupalGet($edit['alias[0][value]']);
-    $this->assertNoText($node4->label(), 'Previous alias no longer works.');
-    $this->assertText($node2->label(), 'Alias works.');
+    // Previous alias should no longer work.
+    $this->assertSession()->pageTextNotContains($node4->label());
+    // Alias should work.
+    $this->assertSession()->pageTextContains($node2->label());
     $this->assertSession()->statusCodeEquals(200);
 
     // Update an existing alias to use a duplicate alias.
@@ -216,8 +234,9 @@ class PathAliasTest extends PathTestBase {
     $edit = [];
     $edit['alias[0][value]'] = $node4_alias;
     $edit['path[0][value]'] = '/node/' . $node3->id();
-    $this->drupalPostForm('admin/config/search/path/edit/' . $pid, $edit, t('Save'));
-    $this->assertRaw(t('The alias %alias is already in use in this language.', ['%alias' => $edit['alias[0][value]']]));
+    $this->drupalGet('admin/config/search/path/edit/' . $pid);
+    $this->submitForm($edit, 'Save');
+    $this->assertSession()->statusMessageContains("The alias {$edit['alias[0][value]']} is already in use in this language.", 'error');
 
     // Create an alias without a starting slash.
     $node5 = $this->drupalCreateNode();
@@ -226,35 +245,35 @@ class PathAliasTest extends PathTestBase {
     $edit['path[0][value]'] = 'node/' . $node5->id();
     $node5_alias = $this->randomMachineName(8);
     $edit['alias[0][value]'] = $node5_alias . '/';
-    $this->drupalPostForm('admin/config/search/path/add', $edit, t('Save'));
+    $this->drupalGet('admin/config/search/path/add');
+    $this->submitForm($edit, 'Save');
 
-    $this->assertUrl('admin/config/search/path/add');
-    $this->assertText('The source path has to start with a slash.');
-    $this->assertText('The alias path has to start with a slash.');
+    $this->assertSession()->addressEquals('admin/config/search/path/add');
+    $this->assertSession()->statusMessageContains('The source path has to start with a slash.', 'error');
+    $this->assertSession()->statusMessageContains('The alias path has to start with a slash.', 'error');
   }
 
   /**
    * Tests alias functionality through the node interfaces.
    */
-  public function testNodeAlias() {
+  public function testNodeAlias(): void {
     // Create test node.
     $node1 = $this->drupalCreateNode();
 
     // Create alias.
     $edit = [];
     $edit['path[0][alias]'] = '/' . $this->randomMachineName(8);
-    $this->drupalPostForm('node/' . $node1->id() . '/edit', $edit, t('Save'));
+    $this->drupalGet('node/' . $node1->id() . '/edit');
+    $this->submitForm($edit, 'Save');
 
     // Confirm that the alias works.
     $this->drupalGet($edit['path[0][alias]']);
-    $this->assertText($node1->label(), 'Alias works.');
+    $this->assertSession()->pageTextContains($node1->label());
     $this->assertSession()->statusCodeEquals(200);
 
     // Confirm the 'canonical' and 'shortlink' URLs.
-    $elements = $this->xpath("//link[contains(@rel, 'canonical') and contains(@href, '" . $edit['path[0][alias]'] . "')]");
-    $this->assertTrue(!empty($elements), 'Page contains canonical link URL.');
-    $elements = $this->xpath("//link[contains(@rel, 'shortlink') and contains(@href, 'node/" . $node1->id() . "')]");
-    $this->assertTrue(!empty($elements), 'Page contains shortlink URL.');
+    $this->assertSession()->elementExists('xpath', "//link[contains(@rel, 'canonical') and contains(@href, '" . $edit['path[0][alias]'] . "')]");
+    $this->assertSession()->elementExists('xpath', "//link[contains(@rel, 'shortlink') and contains(@href, 'node/" . $node1->id() . "')]");
 
     $previous = $edit['path[0][alias]'];
     // Change alias to one containing "exotic" characters.
@@ -272,18 +291,20 @@ class PathAliasTest extends PathTestBase {
       // currently unable to find the upper-case versions of non-ASCII
       // characters.
       // @todo fix this in https://www.drupal.org/node/2607432
+      // cSpell:disable-next-line
       $edit['path[0][alias]'] .= "ïвβéø";
     }
-    $this->drupalPostForm('node/' . $node1->id() . '/edit', $edit, t('Save'));
+    $this->drupalGet('node/' . $node1->id() . '/edit');
+    $this->submitForm($edit, 'Save');
 
     // Confirm that the alias works.
     $this->drupalGet(mb_strtoupper($edit['path[0][alias]']));
-    $this->assertText($node1->label(), 'Changed alias works.');
+    $this->assertSession()->pageTextContains($node1->label());
     $this->assertSession()->statusCodeEquals(200);
 
     // Make sure that previous alias no longer works.
     $this->drupalGet($previous);
-    $this->assertNoText($node1->label(), 'Previous alias no longer works.');
+    $this->assertSession()->pageTextNotContains($node1->label());
     $this->assertSession()->statusCodeEquals(404);
 
     // Create second test node.
@@ -291,17 +312,19 @@ class PathAliasTest extends PathTestBase {
 
     // Set alias to second test node.
     // Leave $edit['path[0][alias]'] the same.
-    $this->drupalPostForm('node/' . $node2->id() . '/edit', $edit, t('Save'));
+    $this->drupalGet('node/' . $node2->id() . '/edit');
+    $this->submitForm($edit, 'Save');
 
     // Confirm that the alias didn't make a duplicate.
-    $this->assertSession()->pageTextContains("The alias {$edit['path[0][alias]']} is already in use in this language.");
+    $this->assertSession()->statusMessageContains("The alias {$edit['path[0][alias]']} is already in use in this language.", 'error');
 
     // Delete alias.
-    $this->drupalPostForm('node/' . $node1->id() . '/edit', ['path[0][alias]' => ''], t('Save'));
+    $this->drupalGet('node/' . $node1->id() . '/edit');
+    $this->submitForm(['path[0][alias]' => ''], 'Save');
 
     // Confirm that the alias no longer works.
     $this->drupalGet($edit['path[0][alias]']);
-    $this->assertNoText($node1->label(), 'Alias was successfully deleted.');
+    $this->assertSession()->pageTextNotContains($node1->label());
     $this->assertSession()->statusCodeEquals(404);
 
     // Create third test node.
@@ -309,11 +332,12 @@ class PathAliasTest extends PathTestBase {
 
     // Set its path alias to an absolute path.
     $edit = ['path[0][alias]' => '/' . $this->randomMachineName(8)];
-    $this->drupalPostForm('node/' . $node3->id() . '/edit', $edit, t('Save'));
+    $this->drupalGet('node/' . $node3->id() . '/edit');
+    $this->submitForm($edit, 'Save');
 
     // Confirm that the alias was converted to a relative path.
     $this->drupalGet(trim($edit['path[0][alias]'], '/'));
-    $this->assertText($node3->label(), 'Alias became relative.');
+    $this->assertSession()->pageTextContains($node3->label());
     $this->assertSession()->statusCodeEquals(200);
 
     // Create fourth test node.
@@ -321,11 +345,12 @@ class PathAliasTest extends PathTestBase {
 
     // Set its path alias to have a trailing slash.
     $edit = ['path[0][alias]' => '/' . $this->randomMachineName(8) . '/'];
-    $this->drupalPostForm('node/' . $node4->id() . '/edit', $edit, t('Save'));
+    $this->drupalGet('node/' . $node4->id() . '/edit');
+    $this->submitForm($edit, 'Save');
 
     // Confirm that the alias was converted to a relative path.
     $this->drupalGet(trim($edit['path[0][alias]'], '/'));
-    $this->assertText($node4->label(), 'Alias trimmed trailing slash.');
+    $this->assertSession()->pageTextContains($node4->label());
     $this->assertSession()->statusCodeEquals(200);
 
     // Create fifth test node.
@@ -333,7 +358,8 @@ class PathAliasTest extends PathTestBase {
 
     // Set a path alias.
     $edit = ['path[0][alias]' => '/' . $this->randomMachineName(8)];
-    $this->drupalPostForm('node/' . $node5->id() . '/edit', $edit, t('Save'));
+    $this->drupalGet('node/' . $node5->id() . '/edit');
+    $this->submitForm($edit, 'Save');
 
     // Delete the node and check that the path alias is also deleted.
     $node5->delete();
@@ -347,7 +373,7 @@ class PathAliasTest extends PathTestBase {
     $edit = ['path[0][alias]' => '0'];
     $this->drupalGet($node6->toUrl('edit-form'));
     $this->submitForm($edit, 'Save');
-    $this->assertSession()->pageTextContains('The alias path has to start with a slash.');
+    $this->assertSession()->statusMessageContains('The alias path has to start with a slash.', 'error');
 
     // Create an invalid alias with two leading slashes and verify that the
     // extra slash is removed when the link is generated. This ensures that URL
@@ -359,7 +385,8 @@ class PathAliasTest extends PathTestBase {
     //   programmatically-created alias instead.
     $alias = $this->randomMachineName(8);
     $edit = ['path[0][alias]' => '//' . $alias];
-    $this->drupalPostForm($node6->toUrl('edit-form'), $edit, t('Save'));
+    $this->drupalGet($node6->toUrl('edit-form'));
+    $this->submitForm($edit, 'Save');
     $this->drupalGet(Url::fromRoute('system.admin_content'));
     // This checks the link href before clicking it, rather than using
     // \Drupal\Tests\BrowserTestBase::assertSession()->addressEquals() after
@@ -368,9 +395,7 @@ class PathAliasTest extends PathTestBase {
     // using \Drupal\Tests\BrowserTestBase::assertSession()->addressEquals()
     // would actually make the test pass unconditionally on the testbot (or
     // anywhere else where Drupal is installed in a subdirectory).
-    $link_xpath = $this->xpath('//a[normalize-space(text())=:label]', [':label' => $node6->getTitle()]);
-    $link_href = $link_xpath[0]->getAttribute('href');
-    $this->assertEquals($link_href, base_path() . $alias);
+    $this->assertSession()->elementAttributeContains('xpath', "//a[normalize-space(text())='{$node6->getTitle()}']", 'href', base_path() . $alias);
     $this->clickLink($node6->getTitle());
     $this->assertSession()->statusCodeEquals(404);
   }
@@ -395,18 +420,22 @@ class PathAliasTest extends PathTestBase {
   /**
    * Tests that duplicate aliases fail validation.
    */
-  public function testDuplicateNodeAlias() {
+  public function testDuplicateNodeAlias(): void {
     // Create one node with a random alias.
     $node_one = $this->drupalCreateNode();
     $edit = [];
     $edit['path[0][alias]'] = '/' . $this->randomMachineName();
-    $this->drupalPostForm('node/' . $node_one->id() . '/edit', $edit, t('Save'));
+    $this->drupalGet('node/' . $node_one->id() . '/edit');
+    $this->submitForm($edit, 'Save');
 
     // Now create another node and try to set the same alias.
     $node_two = $this->drupalCreateNode();
-    $this->drupalPostForm('node/' . $node_two->id() . '/edit', $edit, t('Save'));
-    $this->assertSession()->pageTextContains("The alias {$edit['path[0][alias]']} is already in use in this language.");
-    $this->assertFieldByXPath("//input[@name='path[0][alias]' and contains(@class, 'error')]", $edit['path[0][alias]'], 'Textfield exists and has the error class.');
+    $this->drupalGet('node/' . $node_two->id() . '/edit');
+    $this->submitForm($edit, 'Save');
+    $this->assertSession()->statusMessageContains("The alias {$edit['path[0][alias]']} is already in use in this language.", 'error');
+    $path_alias = $this->assertSession()->fieldExists('path[0][alias]');
+    $this->assertSession()->fieldValueEquals('path[0][alias]', $edit['path[0][alias]']);
+    $this->assertTrue($path_alias->hasClass('error'));
 
     // Behavior here differs with the inline_form_errors module enabled.
     // Enable the inline_form_errors module and try this again. This module
@@ -414,11 +443,12 @@ class PathAliasTest extends PathTestBase {
     // which have invalid input.
     $this->assertTrue($this->container->get('module_installer')->install(['inline_form_errors'], TRUE), 'Installed inline_form_errors.');
     // Attempt to edit the second node again, as before.
-    $this->drupalPostForm('node/' . $node_two->id() . '/edit', $edit, t('Preview'));
+    $this->drupalGet('node/' . $node_two->id() . '/edit');
+    $this->submitForm($edit, 'Preview');
     // This error should still be present next to the field.
     $this->assertSession()->pageTextContains("The alias {$edit['path[0][alias]']} is already in use in this language.");
     // The validation error set for the page should include this text.
-    $this->assertSession()->pageTextContains(t('1 error has been found: URL alias'), 'Form error found with expected text.');
+    $this->assertSession()->statusMessageContains('1 error has been found: URL alias', 'error');
     // The text 'URL alias' should be a link.
     $this->assertSession()->linkExists('URL alias');
     // The link should be to the ID of the URL alias field.
