@@ -112,85 +112,6 @@ class GDToolkit extends ImageToolkitBase {
     );
   }
 
-  /**
-   * {@inheritdoc}
-   */
-  public function __get(string $name) {
-    if ($name === 'resource') {
-      @trigger_error('Accessing the \Drupal\system\Plugin\ImageToolkit\GDToolkit::resource property is deprecated in drupal:10.2.0 and is removed from drupal:11.0.0. Use \Drupal\system\Plugin\ImageToolkit\GDToolkit::image instead. See https://www.drupal.org/node/3265963', E_USER_DEPRECATED);
-      return $this->image;
-    }
-  }
-
-  /**
-   * {@inheritdoc}
-   */
-  public function __set(string $name, mixed $value): void {
-    if ($name === 'resource') {
-      @trigger_error('Setting the \Drupal\system\Plugin\ImageToolkit\GDToolkit::resource property is deprecated in drupal:10.2.0 and is removed from drupal:11.0.0. Use \Drupal\system\Plugin\ImageToolkit\GDToolkit::image instead. See https://www.drupal.org/node/3265963', E_USER_DEPRECATED);
-      $this->image = $value;
-    }
-  }
-
-  /**
-   * {@inheritdoc}
-   */
-  public function __isset(string $name): bool {
-    if ($name === 'resource') {
-      @trigger_error('Checking the \Drupal\system\Plugin\ImageToolkit\GDToolkit::resource property is deprecated in drupal:10.2.0 and is removed from drupal:11.0.0. Use \Drupal\system\Plugin\ImageToolkit\GDToolkit::image instead. See https://www.drupal.org/node/3265963', E_USER_DEPRECATED);
-      return isset($this->image);
-    }
-    return FALSE;
-  }
-
-  /**
-   * {@inheritdoc}
-   */
-  public function __unset(string $name): void {
-    if ($name === 'resource') {
-      @trigger_error('Unsetting the \Drupal\system\Plugin\ImageToolkit\GDToolkit::resource property is deprecated in drupal:10.2.0 and is removed from drupal:11.0.0. Use \Drupal\system\Plugin\ImageToolkit\GDToolkit::image instead. See https://www.drupal.org/node/3265963', E_USER_DEPRECATED);
-      unset($this->image);
-    }
-  }
-
-  /**
-   * Sets the GD image resource.
-   *
-   * @param \GdImage $resource
-   *   The GD image resource.
-   *
-   * @return $this
-   *   An instance of the current toolkit object.
-   *
-   * @deprecated in drupal:10.2.0 and is removed from drupal:11.0.0. Use
-   *   \Drupal\system\Plugin\ImageToolkit\GDToolkit::setImage() instead.
-   *
-   * @see https://www.drupal.org/node/3265963
-   */
-  public function setResource($resource) {
-    @trigger_error(__METHOD__ . '() is deprecated in drupal:10.2.0 and is removed from drupal:11.0.0. Use \Drupal\system\Plugin\ImageToolkit\GDToolkit::setImage() instead. See https://www.drupal.org/node/3265963', E_USER_DEPRECATED);
-    if (!$resource instanceof \GdImage) {
-      throw new \InvalidArgumentException('Invalid resource argument');
-    }
-    return $this->setImage($resource);
-  }
-
-  /**
-   * Retrieves the GD image resource.
-   *
-   * @return \GdImage|null
-   *   The GD image resource, or NULL if not available.
-   *
-   * @deprecated in drupal:10.2.0 and is removed from drupal:11.0.0. Use
-   *   \Drupal\system\Plugin\ImageToolkit\GDToolkit::getImage() instead.
-   *
-   * @see https://www.drupal.org/node/3265963
-   */
-  public function getResource() {
-    @trigger_error(__METHOD__ . '() is deprecated in drupal:10.2.0 and is removed from drupal:11.0.0. Use \Drupal\system\Plugin\ImageToolkit\GDToolkit::getImage() instead. See https://www.drupal.org/node/3265963', E_USER_DEPRECATED);
-    return $this->getImage();
-  }
-
   /**
    * Sets an image or resets existing one.
    *
