@@ -13,7 +13,7 @@ class EntityTestEntityLevelValidator extends ConstraintValidator {
   /**
    * {@inheritdoc}
    */
-  public function validate($value, Constraint $constraint) {
+  public function validate($value, Constraint $constraint): void {
     if ($value->name->value === 'entity-level-violation') {
       $this->context->buildViolation($constraint->message)
         ->addViolation();
