@@ -6,7 +6,7 @@ namespace Drupal\Tests\system\Functional\UpdateSystem;
 
 use Drupal\FunctionalTests\Update\UpdatePathTestBase;
 use Drupal\node\Entity\Node;
-use Drupal\node\Entity\NodeType;
+use Drupal\system\Entity\Action;
 use Drupal\user\Entity\User;
 
 // cspell:ignore hola testblock usuario
@@ -28,7 +28,7 @@ class UpdatePathTestBaseFilledTest extends UpdatePathTestBase {
    * {@inheritdoc}
    */
   protected function setDatabaseDumpFiles() {
-    $this->databaseDumpFiles[] = __DIR__ . '/../../../../tests/fixtures/update/drupal-9.4.0.filled.standard.php.gz';
+    $this->databaseDumpFiles[] = __DIR__ . '/../../../../tests/fixtures/update/drupal-10.3.0.filled.standard.php.gz';
     $this->databaseDumpFiles[] = __DIR__ . '/../../../../tests/fixtures/update/drupal-8.update-test-schema-enabled.php';
     $this->databaseDumpFiles[] = __DIR__ . '/../../../../tests/fixtures/update/drupal-8.update-test-semver-update-n-enabled.php';
   }
@@ -45,7 +45,6 @@ class UpdatePathTestBaseFilledTest extends UpdatePathTestBase {
 
     $expected_node_data = [
       [1, 'article', 'en', 'Test Article - New title'],
-      [2, 'book', 'en', 'Book page'],
       [4, 'page', 'en', 'Test page'],
       [8, 'test_content_type', 'en', 'Test title'],
     ];
@@ -85,7 +84,7 @@ class UpdatePathTestBaseFilledTest extends UpdatePathTestBase {
     $this->assertSession()->pageTextNotContains('Test 12');
     // Make sure all other field labels are there.
     for ($i = 1; $i <= 23; $i++) {
-      if ($i != 12) {
+      if (($i != 11) && ($i != 12)) {
         $this->assertSession()->pageTextContains('Test ' . $i);
       }
     }
@@ -123,7 +122,6 @@ class UpdatePathTestBaseFilledTest extends UpdatePathTestBase {
     $this->assertSession()->pageTextContains('Test Article - New title');
     $this->assertSession()->pageTextContains('test.txt');
     $this->assertSession()->pageTextContains('druplicon.small');
-    $this->assertSession()->responseContains('General discussion');
     $this->assertSession()->pageTextContains('Test Article - New title');
     $this->assertSession()->pageTextContains('Test 1');
     $this->assertSession()->responseContains('0.01');
@@ -153,8 +151,8 @@ class UpdatePathTestBaseFilledTest extends UpdatePathTestBase {
     $this->drupalGet('admin/structure/views/view/test_view');
     $this->assertSession()->pageTextContains('Test view');
 
-    // Make sure the book node exists.
-    $this->drupalGet('admin/structure/book');
+    // Make sure the node/1 node exists.
+    $this->drupalGet('node/1');
     $this->clickLink('Test Article - New title');
     $this->assertSession()->pageTextContains('Body');
     $this->assertSession()->pageTextContains('Tags');
@@ -183,7 +181,6 @@ class UpdatePathTestBaseFilledTest extends UpdatePathTestBase {
     $this->drupalGet('admin/structure/block/manage/testblock');
     $this->assertSession()->checkboxNotChecked('edit-visibility-language-langcodes-es');
     $this->assertSession()->checkboxChecked('edit-visibility-language-langcodes-en');
-    $this->assertSession()->checkboxNotChecked('edit-visibility-entity-bundlenode-bundles-book');
     $this->assertSession()->checkboxChecked('edit-visibility-entity-bundlenode-bundles-test-content-type');
 
     // Make sure our block is still translated.
@@ -303,11 +300,8 @@ class UpdatePathTestBaseFilledTest extends UpdatePathTestBase {
     $this->assertSession()->pageTextContains('Comentario completo');
 
     // Make sure our custom action is still there.
-    $this->drupalGet('admin/config/system/actions');
-    $this->assertSession()->pageTextContains('Test action');
-    $this->drupalGet('admin/config/system/actions/configure/test_action');
-    $this->assertSession()->fieldValueEquals('id', 'test_action');
-    $this->assertSession()->responseContains('drupal.org');
+    $action = Action::load('test_action');
+    $this->assertEquals('Test action', $action->label());
 
     // Make sure our ban still exists.
     $this->drupalGet('admin/config/people/ban');
@@ -338,12 +332,10 @@ class UpdatePathTestBaseFilledTest extends UpdatePathTestBase {
 
     // Make sure our modules are still enabled.
     $expected_enabled_modules = [
-      'action',
       'ban',
       'basic_auth',
       'block',
       'block_content',
-      'book',
       'breakpoint',
       'ckeditor5',
       'comment',
@@ -384,7 +376,6 @@ class UpdatePathTestBaseFilledTest extends UpdatePathTestBase {
       'telephone',
       'text',
       'toolbar',
-      'tracker',
       'update',
       'user',
       'views_ui',
@@ -405,12 +396,6 @@ class UpdatePathTestBaseFilledTest extends UpdatePathTestBase {
     foreach ($expected_enabled_themes as $theme) {
       $this->assertTrue($this->container->get('theme_handler')->themeExists($theme), 'The "' . $theme . '" is still enabled.');
     }
-
-    // Ensure that the Book module's node type does not have duplicated enforced
-    // dependencies.
-    // @see system_post_update_fix_enforced_dependencies()
-    $book_node_type = NodeType::load('book');
-    $this->assertEquals(['enforced' => ['module' => ['book']]], $book_node_type->get('dependencies'));
   }
 
   /**
