@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\system\Kernel\Common;
 
 use Drupal\Core\Extension\ExtensionDiscovery;
@@ -15,7 +17,7 @@ class SystemListingTest extends KernelTestBase {
   /**
    * Tests that files in different directories take precedence as expected.
    */
-  public function testDirectoryPrecedence() {
+  public function testDirectoryPrecedence(): void {
     // Define the module files we will search for, and the directory precedence
     // we expect.
     $expected_directories = [
@@ -33,7 +35,7 @@ class SystemListingTest extends KernelTestBase {
     foreach ($expected_directories as $module => $directories) {
       foreach ($directories as $directory) {
         $filename = "$directory/$module/$module.info.yml";
-        $this->assertTrue(file_exists($this->root . '/' . $filename), format_string('@filename exists.', ['@filename' => $filename]));
+        $this->assertFileExists($this->root . '/' . $filename);
       }
     }
 
@@ -45,26 +47,23 @@ class SystemListingTest extends KernelTestBase {
     foreach ($expected_directories as $module => $directories) {
       $expected_directory = array_shift($directories);
       $expected_uri = "$expected_directory/$module/$module.info.yml";
-      $this->assertEqual($files[$module]->getPathname(), $expected_uri, format_string('Module @actual was found at @expected.', [
-        '@actual' => $files[$module]->getPathname(),
-        '@expected' => $expected_uri,
-      ]));
+      $module_path = $files[$module]->getPathname();
+      $this->assertEquals($expected_uri, $module_path, "Module $module_path was found at $expected_uri.");
     }
   }
 
   /**
-   * Tests that directories matching file_scan_ignore_directories are ignored
+   * Tests that directories matching file_scan_ignore_directories are ignored.
    */
-  public function testFileScanIgnoreDirectory() {
+  public function testFileScanIgnoreDirectory(): void {
     $listing = new ExtensionDiscovery($this->root, FALSE);
     $listing->setProfileDirectories(['core/profiles/testing']);
     $files = $listing->scan('module');
     $this->assertArrayHasKey('drupal_system_listing_compatible_test', $files);
 
-    // Reset the static to force a rescan of the directories.
+    // Reset the static to force a re-scan of the directories.
     $reflected_class = new \ReflectionClass(ExtensionDiscovery::class);
     $reflected_property = $reflected_class->getProperty('files');
-    $reflected_property->setAccessible(TRUE);
     $reflected_property->setValue($reflected_class, []);
 
     $this->setSetting('file_scan_ignore_directories', ['drupal_system_listing_compatible_test']);
