@@ -9,6 +9,7 @@ use Drupal\Core\Language\LanguageInterface;
 use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
 use Drupal\Core\Plugin\PluginBase as ComponentPluginBase;
 use Drupal\Core\Render\Element;
+use Drupal\Core\Security\TrustedCallbackInterface;
 use Drupal\Core\StringTranslation\TranslatableMarkup;
 use Drupal\views\Plugin\views\display\DisplayPluginBase;
 use Drupal\views\ViewExecutable;
@@ -20,25 +21,23 @@ use Symfony\Component\DependencyInjection\ContainerInterface;
  * Via the @Plugin definition the plugin may specify a theme function or
  * template to be used for the plugin. It also can auto-register the theme
  * implementation for that file or function.
- * - theme: the theme implementation to use in the plugin. This may be the name
- *   of the function (without theme_ prefix) or the template file (without
- *   template engine extension).
- *   If a template file should be used, the file has to be placed in the
- *   module's templates folder.
- *   Example: theme = "mymodule_row" of module "mymodule" will implement
- *   mymodule-row.html.twig in the [..]/modules/mymodule/templates folder.
+ * - theme: the theme implementation to use in the plugin. This must be the
+ *   name of the template file (without template engine extension). The file
+ *   has to be placed in the module's templates folder.
+ *   Example: theme = "my_module_row" of module "my_module" will implement
+ *   my_module-row.html.twig in the [..]/modules/my_module/templates folder.
  * - register_theme: (optional) When set to TRUE (default) the theme is
  *   registered automatically. When set to FALSE the plugin reuses an existing
  *   theme implementation, defined by another module or views plugin.
- * - theme_file: (optional) the location of an include file that may hold the
- *   theme or preprocess function. The location has to be relative to module's
- *   root directory.
+ * - theme_file: (optional) the location of an include file that holds any
+ *   preprocess functions. The location has to be relative to the module's root
+ *   directory.
  * - module: machine name of the module. It must be present for any plugin that
  *   wants to register a theme.
  *
  * @ingroup views_plugins
  */
-abstract class PluginBase extends ComponentPluginBase implements ContainerFactoryPluginInterface, ViewsPluginInterface, DependentPluginInterface {
+abstract class PluginBase extends ComponentPluginBase implements ContainerFactoryPluginInterface, ViewsPluginInterface, DependentPluginInterface, TrustedCallbackInterface {
 
   /**
    * Include negotiated languages when listing languages.
@@ -87,7 +86,7 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
   public $displayHandler;
 
   /**
-   * Plugins's definition
+   * Plugins' definition.
    *
    * @var array
    */
@@ -107,13 +106,18 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
    */
   protected $renderer;
 
+  /**
+   * The handler position.
+   */
+  public int $position;
+
   /**
    * Constructs a PluginBase object.
    *
    * @param array $configuration
    *   A configuration array containing information about the plugin instance.
    * @param string $plugin_id
-   *   The plugin_id for the plugin instance.
+   *   The plugin ID for the plugin instance.
    * @param mixed $plugin_definition
    *   The plugin implementation definition.
    */
@@ -133,8 +137,9 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
   /**
    * {@inheritdoc}
    */
-  public function init(ViewExecutable $view, DisplayPluginBase $display, array &$options = NULL) {
+  public function init(ViewExecutable $view, DisplayPluginBase $display, ?array &$options = NULL) {
     $this->view = $view;
+    $this->options = $this->options ?? [];
     $this->setOptionDefaults($this->options, $this->defineOptions());
     $this->displayHandler = $display;
 
@@ -144,12 +149,12 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
   /**
    * Information about options for all kinds of purposes will be held here.
    * @code
-   * 'option_name' => array(
+   * 'option_name' => [
    *  - 'default' => default value,
    *  - 'contains' => (optional) array of items this contains, with its own
    *      defaults, etc. If contains is set, the default will be ignored and
-   *      assumed to be array().
-   *  ),
+   *      assumed to be [].
+   *  ],
    * @endcode
    *
    * @return array
@@ -244,7 +249,7 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
           continue;
         }
 
-        $this->unpackOptions($storage[$key], $value, isset($definition[$key]['contains']) ? $definition[$key]['contains'] : [], $all, FALSE);
+        $this->unpackOptions($storage[$key], $value, $definition[$key]['contains'] ?? [], $all, FALSE);
       }
       elseif ($all || !empty($definition[$key])) {
         $storage[$key] = $value;
@@ -267,7 +272,14 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
     // be moved into one because of the $form_state->getValues() hierarchy. Those
     // elements can add a #fieldset => 'fieldset_name' property, and they'll
     // be moved to their fieldset during pre_render.
-    $form['#pre_render'][] = [get_class($this), 'preRenderAddFieldsetMarkup'];
+    $form['#pre_render'][] = [static::class, 'preRenderAddFieldsetMarkup'];
+  }
+
+  /**
+   * {@inheritdoc}
+   */
+  public static function trustedCallbacks() {
+    return ['preRenderAddFieldsetMarkup'];
   }
 
   /**
@@ -332,8 +344,9 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
   }
 
   /**
-   * Replaces Views' tokens in a given string. The resulting string will be
-   * sanitized with Xss::filterAdmin.
+   * Replaces Views' tokens in a given string.
+   *
+   * The resulting string will be sanitized with Xss::filterAdmin.
    *
    * @param $text
    *   Unsanitized string with possible tokens.
@@ -355,8 +368,8 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
     foreach ($tokens as $token => $replacement) {
       // Twig wants a token replacement array stripped of curly-brackets.
       // Some Views tokens come with curly-braces, others do not.
-      // @todo: https://www.drupal.org/node/2544392
-      if (strpos($token, '{{') !== FALSE) {
+      // @todo https://www.drupal.org/node/2544392
+      if (str_contains($token, '{{')) {
         // Twig wants a token replacement array stripped of curly-brackets.
         $token = trim(str_replace(['{{', '}}'], '', $token));
       }
@@ -364,21 +377,21 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
       // Check for arrays in Twig tokens. Internally these are passed as
       // dot-delimited strings, but need to be turned into associative arrays
       // for parsing.
-      if (strpos($token, '.') === FALSE) {
+      if (!str_contains($token, '.')) {
         // We need to validate tokens are valid Twig variables. Twig uses the
         // same variable naming rules as PHP.
         // @see http://php.net/manual/language.variables.basics.php
-        assert('preg_match(\'/^[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*$/\', $token) === 1', 'Tokens need to be valid Twig variables.');
+        assert(preg_match('/^[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*$/', $token) === 1, 'Tokens need to be valid Twig variables.');
         $twig_tokens[$token] = $replacement;
       }
       else {
         $parts = explode('.', $token);
         $top = array_shift($parts);
-        assert('preg_match(\'/^[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*$/\', $top) === 1', 'Tokens need to be valid Twig variables.');
+        assert(preg_match('/^[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*$/', $top) === 1, 'Tokens need to be valid Twig variables.');
         $token_array = [array_pop($parts) => $replacement];
         foreach (array_reverse($parts) as $key) {
           // The key could also be numeric (array index) so allow that.
-          assert('is_numeric($key) || (preg_match(\'/^[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*$/\', $key) === 1)', 'Tokens need to be valid Twig variables.');
+          assert(is_numeric($key) || preg_match('/^[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*$/', $key) === 1, 'Tokens need to be valid Twig variables.');
           $token_array = [$key => $token_array];
         }
         if (!isset($twig_tokens[$top])) {
@@ -400,15 +413,15 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
         '#post_render' => [
           function ($children, $elements) {
             return Xss::filterAdmin($children);
-          }
+          },
         ],
       ];
 
       // Currently you cannot attach assets to tokens with
-      // Renderer::renderPlain(). This may be unnecessarily limiting. Consider
+      // Renderer::renderInIsolation(). This may be unnecessarily limiting. Consider
       // using Renderer::executeInRenderContext() instead.
-      // @todo: https://www.drupal.org/node/2566621
-      return (string) $this->getRenderer()->renderPlain($build);
+      // @todo https://www.drupal.org/node/2566621
+      return (string) $this->getRenderer()->renderInIsolation($build);
     }
     else {
       return Xss::filterAdmin($text);
@@ -547,7 +560,7 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
    *   Only configurable languages and languages that are in $current_values are
    *   included in the list.
    */
-  protected function listLanguages($flags = LanguageInterface::STATE_ALL, array $current_values = NULL) {
+  protected function listLanguages($flags = LanguageInterface::STATE_ALL, ?array $current_values = NULL) {
     $manager = \Drupal::languageManager();
     $languages = $manager->getLanguages($flags);
     $list = [];
@@ -595,7 +608,7 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
           // If this (non-configurable) type is among the current values,
           // add that option too, so it is not lost. If not among the current
           // values, skip displaying it to avoid user confusion.
-          if (isset($type['name']) && !isset($list[$id]) && in_array($id, $current_values)) {
+          if (isset($type['name']) && !isset($list[$id]) && in_array($id, $current_values, TRUE)) {
             $list[$id] = $this->t('@type language selected for page', ['@type' => $type['name']]);
           }
         }
