@@ -25,11 +25,6 @@ use Drupal\Core\Test\TestRun;
 use Drupal\Core\Test\TestRunnerKernel;
 use Drupal\Core\Test\TestRunResultsStorageInterface;
 use Drupal\Core\Test\TestDiscovery;
-use Drupal\BuildTests\Framework\BuildTestBase;
-use Drupal\FunctionalJavascriptTests\WebDriverTestBase;
-use Drupal\KernelTests\KernelTestBase;
-use Drupal\Tests\BrowserTestBase;
-use Drupal\TestTools\PhpUnitCompatibility\ClassWriter;
 use PHPUnit\Framework\TestCase;
 use PHPUnit\Runner\Version;
 use Symfony\Component\Console\Output\ConsoleOutput;
@@ -515,7 +510,6 @@ function simpletest_script_init() {
   $autoloader = require_once __DIR__ . '/../../autoload.php';
   // The PHPUnit compatibility layer needs to be available to autoload tests.
   $autoloader->add('Drupal\\TestTools', __DIR__ . '/../tests');
-  ClassWriter::mutateTestBase($autoloader);
 
   // Get URL from arguments.
   if (!empty($args['url'])) {
@@ -768,8 +762,8 @@ function simpletest_script_execute_batch(TestRunResultsStorageInterface $test_ru
       ];
     }
 
-    // Wait for children every 2ms.
-    usleep(2000);
+    // Wait for children every 200ms.
+    usleep(200000);
 
     // Check if some children finished.
     foreach ($children as $cid => $child) {
@@ -821,18 +815,18 @@ function simpletest_script_execute_batch(TestRunResultsStorageInterface $test_ru
  * Run a PHPUnit-based test.
  */
 function simpletest_script_run_phpunit(TestRun $test_run, $class) {
-  $reflection = new \ReflectionClass($class);
-  if ($reflection->hasProperty('runLimit')) {
-    set_time_limit($reflection->getStaticPropertyValue('runLimit'));
-  }
+  global $args;
 
   $runner = PhpUnitTestRunner::create(\Drupal::getContainer());
-  $results = $runner->execute($test_run, [$class], $status);
+  $start = microtime(TRUE);
+  $results = $runner->execute($test_run, $class, $status, $args['color']);
+  $time = microtime(TRUE) - $start;
+
   $runner->processPhpUnitResults($test_run, $results);
 
   $summaries = $runner->summarizeResults($results);
   foreach ($summaries as $class => $summary) {
-    simpletest_script_reporter_display_summary($class, $summary);
+    simpletest_script_reporter_display_summary($class, $summary, $time);
   }
   return $status;
 }
@@ -920,47 +914,40 @@ function simpletest_script_get_test_list() {
       echo (string) $e;
       exit(SIMPLETEST_SCRIPT_EXIT_EXCEPTION);
     }
-    // Ensure that tests marked explicitly as @group #slow are run at the
-    // beginning of each job.
-    if (key($groups) === '#slow') {
-      $slow_tests = array_keys(array_shift($groups));
+    // If the tests are run in parallel jobs, ensure that slow tests are
+    // distributed between each job.
+    if ((int) $args['ci-parallel-node-total'] > 1) {
+      if (key($groups) === '#slow') {
+        $slow_tests = array_keys(array_shift($groups));
+      }
     }
-    $not_slow_tests = [];
+    $all_tests = [];
     foreach ($groups as $group => $tests) {
-      $not_slow_tests = array_merge($not_slow_tests, array_keys($tests));
+      if ($group === '#slow') {
+        $slow_group = $tests;
+      }
+      else {
+        $all_tests = array_merge($all_tests, array_keys($tests));
+      }
     }
-    // Filter slow tests out of the not slow tests and ensure a unique list
-    // since tests may appear in more than one group.
-    $not_slow_tests = array_unique(array_diff($not_slow_tests, $slow_tests));
-
-    // If the tests are not being run in parallel, then ensure slow tests run
-    // all together first.
-    if ((int) $args['ci-parallel-node-total'] <= 1 ) {
-      sort_tests_by_type_and_methods($slow_tests);
-      sort_tests_by_type_and_methods($not_slow_tests);
-      $test_list = array_merge($slow_tests, $not_slow_tests);
-    }
-    else {
-      // Sort all tests by the number of public methods on the test class.
-      // This is a proxy for the approximate time taken to run the test,
-      // which is used in combination with @group #slow to start the slowest tests
-      // first and distribute tests between test runners.
-      sort_tests_by_public_method_count($slow_tests);
-      sort_tests_by_public_method_count($not_slow_tests);
-
-      // Now set up a bin per test runner.
-      $bin_count = (int) $args['ci-parallel-node-total'];
-
-      // Now loop over the slow tests and add them to a bin one by one, this
-      // distributes the tests evenly across the bins.
-      $binned_slow_tests = place_tests_into_bins($slow_tests, $bin_count);
-      $slow_tests_for_job = $binned_slow_tests[$args['ci-parallel-node-index'] - 1];
-
-      // And the same for the rest of the tests.
-      $binned_other_tests = place_tests_into_bins($not_slow_tests, $bin_count);
-      $other_tests_for_job = $binned_other_tests[$args['ci-parallel-node-index'] - 1];
-      $test_list = array_merge($slow_tests_for_job, $other_tests_for_job);
+    // If no type has been set, order the tests alphabetically by test namespace
+    // so that unit tests run last. This takes advantage of the fact that Build,
+    // Functional, Functional JavaScript, Kernel, Unit roughly corresponds to
+    // test time.
+    usort($all_tests, function ($a, $b) {
+      $slice = function ($class) {
+        $parts = explode('\\', $class);
+        return implode('\\', array_slice($parts, 3));
+      };
+      return $slice($a) > $slice($b) ? 1 : -1;
+    });
+    // If the tests are not being run in parallel, then ensure slow tests run all
+    // together first.
+    if ((int) $args['ci-parallel-node-total'] <= 1 && !empty($slow_group)) {
+      $all_tests = array_merge(array_keys($slow_group), $all_tests);
     }
+    $test_list = array_unique($all_tests);
+    $test_list = array_diff($test_list, $slow_tests);
   }
   else {
     if ($args['class']) {
@@ -1040,106 +1027,15 @@ function simpletest_script_get_test_list() {
     exit(SIMPLETEST_SCRIPT_EXIT_FAILURE);
   }
 
+  if ((int) $args['ci-parallel-node-total'] > 1) {
+    $slow_tests_per_job = (int) ceil(count($slow_tests) / $args['ci-parallel-node-total']);
+    $tests_per_job = (int) ceil(count($test_list) / $args['ci-parallel-node-total']);
+    $test_list = array_merge(array_slice($slow_tests, ($args['ci-parallel-node-index'] -1) * $slow_tests_per_job, $slow_tests_per_job), array_slice($test_list, ($args['ci-parallel-node-index'] - 1) * $tests_per_job, $tests_per_job));
+  }
+
   return $test_list;
 }
 
-/**
- * Sort tests by test type and number of public methods.
- */
-function sort_tests_by_type_and_methods(array &$tests) {
-  usort($tests, function ($a, $b) {
-    if (get_test_type_weight($a) === get_test_type_weight($b)) {
-      return get_test_class_method_count($b) <=> get_test_class_method_count($a);
-    }
-    return get_test_type_weight($b) <=> get_test_type_weight($a);
-  });
-}
-
-/**
- * Sort tests by the number of public methods in the test class.
- *
- * Tests with several methods take longer to run than tests with a single
- * method all else being equal, so this allows tests runs to be sorted by
- * approximately the slowest to fastest tests. Tests that are exceptionally
- * slow can be added to the '#slow' group so they are placed first in each
- * test run regardless of the number of methods.
- *
- * @param string[] $tests
- *   An array of test class names.
- */
-function sort_tests_by_public_method_count(array &$tests): void {
-  usort($tests, function ($a, $b) {
-    return get_test_class_method_count($b) <=> get_test_class_method_count($a);
-  });
-}
-
-/**
- * Weights a test class based on which test base class it extends.
- *
- * @param string $class
- *   The test class name.
- */
-function get_test_type_weight(string $class): int {
-  return match(TRUE) {
-    is_subclass_of($class, WebDriverTestBase::class) => 3,
-    is_subclass_of($class, BrowserTestBase::class) => 2,
-    is_subclass_of($class, BuildTestBase::class) => 2,
-    is_subclass_of($class, KernelTestBase::class) => 1,
-    default => 0,
-  };
-}
-
-/**
- * Get an approximate test method count for a test class.
- *
- * @param string $class
- *   The test class name.
- */
-function get_test_class_method_count(string $class): int {
-  $reflection = new \ReflectionClass($class);
-  $count = 0;
-  foreach ($reflection->getMethods(\ReflectionMethod::IS_PUBLIC) as $method) {
-    // If a method uses a dataProvider, increase the count by 20 since data
-    // providers result in a single method running multiple times.
-    $comments = $method->getDocComment();
-    preg_match_all('#@(.*?)\n#s', $comments, $annotations);
-    foreach ($annotations[1] as $annotation) {
-      if (str_starts_with($annotation, 'dataProvider')) {
-        $count = $count + 20;
-        continue;
-      }
-    }
-    $count++;
-  }
-  return $count;
-}
-
-/**
- * Distribute tests into bins.
- *
- * The given array of tests is split into the available bins. The distribution
- * starts with the first test, placing the first test in the first bin, the
- * second test in the second bin and so on. This results each bin having a
- * similar number of test methods to run in total.
- *
- * @param string[] $tests
- *   An array of test class names.
- * @param int $bin_count
- *   The number of bins available.
- *
- * @return array
- *   An associative array of bins and the test class names in each bin.
- */
- function place_tests_into_bins(array $tests, int $bin_count) {
-  // Create a bin corresponding to each parallel test job.
-  $bins = array_fill(0, $bin_count, []);
-  // Go through each test and add them to one bin at a time.
-  foreach ($tests as $key => $test) {
-    $bins[($key % $bin_count)][] = $test;
-  }
-  return $bins;
-}
-
 /**
  * Initialize the reporter.
  */
@@ -1186,14 +1082,17 @@ function simpletest_script_reporter_init() {
  *   The test class name that was run.
  * @param array $results
  *   The assertion results using #pass, #fail, #exception, #debug array keys.
+ * @param int|null $duration
+ *   The time taken for the test to complete.
  */
-function simpletest_script_reporter_display_summary($class, $results) {
+function simpletest_script_reporter_display_summary($class, $results, $duration = NULL) {
   // Output all test results vertically aligned.
   // Cut off the class name after 60 chars, and pad each group with 3 digits
   // by default (more than 999 assertions are rare).
-  $output = vsprintf('%-60.60s %10s %9s %14s %12s', [
+  $output = vsprintf('%-60.60s %10s %5s %9s %14s %12s', [
     $class,
     $results['#pass'] . ' passes',
+    isset($duration) ? ceil($duration) . 's' : '',
     !$results['#fail'] ? '' : $results['#fail'] . ' fails',
     !$results['#exception'] ? '' : $results['#exception'] . ' exceptions',
     !$results['#debug'] ? '' : $results['#debug'] . ' messages',
@@ -1231,7 +1130,7 @@ function simpletest_script_reporter_write_xml_results(TestRunResultsStorageInter
         }
         $test_class = $result->test_class;
         if (!isset($xml_files[$test_class])) {
-          $doc = new DomDocument('1.0', 'utf-8');
+          $doc = new DomDocument('1.0');
           $root = $doc->createElement('testsuite');
           $root = $doc->appendChild($root);
           $xml_files[$test_class] = ['doc' => $doc, 'suite' => $root];
@@ -1351,7 +1250,7 @@ function simpletest_script_format_result($result) {
   if ($args['non-html']) {
     $message = Html::decodeEntities($message);
   }
-  $lines = explode("\n", wordwrap($message), 76);
+  $lines = explode("\n", $message);
   foreach ($lines as $line) {
     echo "    $line\n";
   }
