@@ -100,9 +100,9 @@ JS);
       $current_page_ajax_response_count = 0;
     }
 
-    // Detect unnecessary AJAX request waits and inform the test author.
+    // Detect unnecessary AJAX request waits.
     if ($drupal_ajax_request_count === $current_page_ajax_response_count) {
-      @trigger_error(sprintf('%s called unnecessarily in a test is deprecated in drupal:10.2.0 and will throw an exception in drupal:11.0.0. See https://www.drupal.org/node/3401201', __METHOD__), E_USER_DEPRECATED);
+      throw new \RuntimeException('There are no AJAX requests to wait for.');
     }
 
     // Detect untracked AJAX requests. This will alert if the detection is
@@ -536,7 +536,7 @@ JS;
    *
    * @see Drupal\Component\Utility\Html::escape()
    */
-  protected function escapeHtml($raw): string {
+  protected function escapeHtml($raw) {
     return htmlspecialchars($raw, ENT_NOQUOTES | ENT_SUBSTITUTE, 'UTF-8');
   }
 
