@@ -9,7 +9,7 @@ namespace Drupal\FunctionalTests\Installer;
  *
  * @group Installer
  */
-class InstallerExistingConfigNoConfigTest extends InstallerExistingConfigTestBase {
+class InstallerExistingConfigNoConfigTest extends InstallerConfigDirectoryTestBase {
 
   /**
    * {@inheritdoc}
@@ -28,8 +28,8 @@ class InstallerExistingConfigNoConfigTest extends InstallerExistingConfigTestBas
   /**
    * {@inheritdoc}
    */
-  protected function getConfigTarball() {
-    return __DIR__ . '/../../../fixtures/config_install/testing_config_install_no_config.tar.gz';
+  protected function getConfigLocation() {
+    return __DIR__ . '/../../../fixtures/config_install/testing_config_install_no_config';
   }
 
   /**
