@@ -44,7 +44,7 @@ class InstallerExistingConfigNoSystemSiteTest extends InstallerConfigDirectoryTe
   /**
    * {@inheritdoc}
    */
-  protected function getConfigLocation(): string {
+  protected function getConfigLocation() {
     return __DIR__ . '/../../../fixtures/config_install/testing_config_install';
   }
 
