@@ -37,7 +37,7 @@ class InstallerExistingConfigTest extends InstallerConfigDirectoryTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function getConfigLocation(): string {
+  protected function getConfigLocation() {
     return __DIR__ . '/../../../fixtures/config_install/testing_config_install';
   }
 
