@@ -1,9 +1,13 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\FunctionalTests\Installer;
 
 use Drupal\Core\Language\LanguageManager;
 
+// cspell:ignore xoxo
+
 /**
  * Verifies that the installer language list combines local and remote languages.
  *
@@ -11,6 +15,11 @@ use Drupal\Core\Language\LanguageManager;
  */
 class InstallerLanguagePageTest extends InstallerTestBase {
 
+  /**
+   * {@inheritdoc}
+   */
+  protected $defaultTheme = 'stark';
+
   /**
    * Installer step: Select language.
    */
@@ -22,13 +31,13 @@ class InstallerLanguagePageTest extends InstallerTestBase {
     // Check that all predefined languages show up with their native names.
     $this->visitInstaller();
     foreach (LanguageManager::getStandardLanguageList() as $langcode => $names) {
-      $this->assertOption('edit-langcode', $langcode);
-      $this->assertRaw('>' . $names[1] . '<');
+      $this->assertSession()->optionExists('edit-langcode', $langcode);
+      $this->assertSession()->responseContains('>' . $names[1] . '<');
     }
 
     // Check that our custom one shows up with the file name indicated language.
-    $this->assertOption('edit-langcode', 'xoxo');
-    $this->assertRaw('>xoxo<');
+    $this->assertSession()->optionExists('edit-langcode', 'xoxo');
+    $this->assertSession()->responseContains('>xoxo<');
 
     parent::setUpLanguage();
   }
@@ -36,9 +45,9 @@ class InstallerLanguagePageTest extends InstallerTestBase {
   /**
    * Confirms that the installation succeeded.
    */
-  public function testInstalled() {
-    $this->assertUrl('user/1');
-    $this->assertResponse(200);
+  public function testInstalled(): void {
+    $this->assertSession()->addressEquals('user/1');
+    $this->assertSession()->statusCodeEquals(200);
   }
 
 }
