@@ -400,8 +400,6 @@ class ConfigSchemaTest extends KernelTestBase {
 
   /**
    * Tests configuration value data type enforcement using schemas.
-   *
-   * @group legacy
    */
   public function testConfigSaveWithSchema(): void {
     $untyped_values = [
@@ -422,11 +420,10 @@ class ConfigSchemaTest extends KernelTestBase {
         'string' => 1,
       ],
       'sequence' => [1, 0, 1],
-      'sequence_bc' => [1, 0, 1],
-      'sequence_bc_root' => [['id' => 'foo', 'value' => 0], ['id' => 'bar', 'value' => 1]],
       // Not in schema and therefore should be left untouched.
       'not_present_in_schema' => TRUE,
     ];
+
     $untyped_to_typed = $untyped_values;
 
     $typed_values = [
@@ -445,13 +442,10 @@ class ConfigSchemaTest extends KernelTestBase {
         'string' => '1',
       ],
       'sequence' => [TRUE, FALSE, TRUE],
-      'sequence_bc' => [TRUE, FALSE, TRUE],
-      'sequence_bc_root' => [['id' => 'foo', 'value' => FALSE], ['id' => 'bar', 'value' => TRUE]],
       'not_present_in_schema' => TRUE,
     ];
 
     // Save config which has a schema that enforces types.
-    $this->expectDeprecation("The definition for the 'config_schema_test.schema_data_types.sequence_bc' sequence declares the type of its items in a way that is deprecated in drupal:8.0.0 and is removed from drupal:11.0.0. See https://www.drupal.org/node/2442603");
     $this->config('config_schema_test.schema_data_types')
       ->setData($untyped_to_typed)
       ->save();
@@ -852,21 +846,15 @@ class ConfigSchemaTest extends KernelTestBase {
     ], $definition['mapping']['breed']);
   }
 
-  /**
-   * @group legacy
-   */
   public function testLangcodeRequiredIfTranslatableValuesConstraintError(): void {
     $config = \Drupal::configFactory()->getEditable('config_test.foo');
 
+    $this->expectException(\LogicException::class);
+    $this->expectExceptionMessage('The LangcodeRequiredIfTranslatableValues constraint is applied to \'config_test.foo::broken_langcode_required\'. This constraint can only operate on the root object being validated.');
+
     $config
       ->set('broken_langcode_required.foo', 'bar')
       ->save();
-
-    $this->expectDeprecation('The LangcodeRequiredIfTranslatableValues constraint can only be applied to the root object being validated, using the \'config_object\' schema type on \'config_test.foo::broken_langcode_required\' is deprecated in drupal:10.3.0 and will trigger a \LogicException in drupal:11.0.0. See https://www.drupal.org/node/3459863');
-    $violations = \Drupal::service('config.typed')->createFromNameAndData($config->getName(), $config->get())
-      ->validate();
-
-    $this->assertCount(0, $violations);
   }
 
 }
