@@ -21,10 +21,7 @@ final class FinalTestHttpMiddlewareClass implements HttpKernelInterface, Termina
 
   /**
    * {@inheritdoc}
-   *
-   * phpcs:ignore Drupal.Commenting.FunctionComment.VoidReturn
-   * @return void
    */
-  public function terminate(Request $request, Response $response) {}
+  public function terminate(Request $request, Response $response): void {}
 
 }
