@@ -552,28 +552,6 @@ class KeyValueEntityStorageTest extends UnitTestCase {
     }
   }
 
-  /**
-   * @covers ::loadRevision
-   * @group legacy
-   */
-  public function testLoadRevision(): void {
-    $this->expectDeprecation('Drupal\Core\Entity\KeyValueStore\KeyValueEntityStorage::loadRevision() is deprecated in drupal:10.1.0 and is removed from drupal:11.0.0. Use \Drupal\Core\Entity\RevisionableStorageInterface::loadRevision instead. See https://www.drupal.org/node/3294237');
-    $this->setUpKeyValueEntityStorage();
-
-    $this->assertNull($this->entityStorage->loadRevision(1));
-  }
-
-  /**
-   * @covers ::deleteRevision
-   * @group legacy
-   */
-  public function testDeleteRevision(): void {
-    $this->expectDeprecation('Drupal\Core\Entity\KeyValueStore\KeyValueEntityStorage::deleteRevision() is deprecated in drupal:10.1.0 and is removed from drupal:11.0.0. Use \Drupal\Core\Entity\RevisionableStorageInterface::deleteRevision instead. See https://www.drupal.org/node/3294237');
-    $this->setUpKeyValueEntityStorage();
-
-    $this->assertNull($this->entityStorage->deleteRevision(1));
-  }
-
   /**
    * @covers ::delete
    * @covers ::doDelete
