@@ -4,6 +4,8 @@ declare(strict_types=1);
 
 namespace Drupal\Tests;
 
+// cspell:ignore datalen PSFS_FEED_ME writeable
+
 /**
  * Captures output to a stream and stores it for retrieval.
  */
@@ -11,15 +13,12 @@ class StreamCapturer extends \php_user_filter {
 
   public static $cache = '';
 
-  #[\ReturnTypeWillChange]
-  public function filter($in, $out, &$consumed, $closing) {
+  public function filter($in, $out, &$consumed, $closing): int {
     while ($bucket = stream_bucket_make_writeable($in)) {
       self::$cache .= $bucket->data;
-      // cSpell:disable-next-line
       $consumed += $bucket->datalen;
       stream_bucket_append($out, $bucket);
     }
-    // cSpell:disable-next-line
     return PSFS_FEED_ME;
   }
 
