@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests;
 
 use Behat\Mink\Exception\ExpectationException;
@@ -10,6 +12,12 @@ use Behat\Mink\Exception\ElementNotFoundException;
 use Behat\Mink\Session;
 use Drupal\Component\Utility\Html;
 use Drupal\Core\Url;
+use PHPUnit\Framework\Assert;
+use PHPUnit\Framework\AssertionFailedError;
+use PHPUnit\Framework\Constraint\ArrayHasKey;
+use PHPUnit\Framework\Constraint\IsIdentical;
+use PHPUnit\Framework\Constraint\IsEqual;
+use PHPUnit\Framework\Constraint\LogicalNot;
 
 /**
  * Defines a class with methods for asserting presence of elements during tests.
@@ -37,22 +45,90 @@ class WebAssert extends MinkWebAssert {
   }
 
   /**
-   * {@inheritdoc}
+   * Trims the base URL from the URL.
+   *
+   * @param string|\Drupal\Core\Url $url
+   *   A url string, or object.
+   * @param bool $include_query
+   *   Whether to include the query string in the return value.
+   *
+   * @return string
    */
-  protected function cleanUrl($url) {
+  protected function cleanUrl(string|Url $url, bool $include_query = FALSE) {
     if ($url instanceof Url) {
       $url = $url->setAbsolute()->toString();
     }
     // Strip the base URL from the beginning for absolute URLs.
-    if ($this->baseUrl !== '' && strpos($url, $this->baseUrl) === 0) {
+    if ($this->baseUrl !== '' && str_starts_with($url, $this->baseUrl)) {
       $url = substr($url, strlen($this->baseUrl));
     }
+    $parts = parse_url($url);
     // Make sure there is a forward slash at the beginning of relative URLs for
     // consistency.
-    if (parse_url($url, PHP_URL_HOST) === NULL && strpos($url, '/') !== 0) {
-      $url = "/$url";
+    if (empty($parts['host']) && !str_starts_with($url, '/')) {
+      $parts['path'] = '/' . $parts['path'];
     }
-    return parent::cleanUrl($url);
+    $fragment = empty($parts['fragment']) ? '' : '#' . $parts['fragment'];
+    $path = empty($parts['path']) ? '/' : $parts['path'];
+    $query = $include_query && !empty($parts['query']) ? '?' . $parts['query'] : '';
+
+    return preg_replace('/^\/[^\.\/]+\.php\//', '/', $path) . $query . $fragment;
+  }
+
+  /**
+   * Asserts that the current response header has a specific entry.
+   *
+   * @param string $name
+   *   The name of the header entry to check existence of.
+   * @param string $message
+   *   The failure message.
+   */
+  public function responseHeaderExists(string $name, string $message = ''): void {
+    if ($message === '') {
+      $message = "Failed asserting that the response has a '$name' header.";
+    }
+    $headers = $this->session->getResponseHeaders();
+    $constraint = new ArrayHasKey($name);
+    Assert::assertThat($headers, $constraint, $message);
+  }
+
+  /**
+   * Asserts that the current response header does not have a specific entry.
+   *
+   * @param string $name
+   *   The name of the header entry to check existence of.
+   * @param string $message
+   *   The failure message.
+   */
+  public function responseHeaderDoesNotExist(string $name, string $message = ''): void {
+    if ($message === '') {
+      $message = "Failed asserting that the response does not have a '$name' header.";
+    }
+    $headers = $this->session->getResponseHeaders();
+    $constraint = new LogicalNot(
+      new ArrayHasKey($name)
+    );
+    Assert::assertThat($headers, $constraint, $message);
+  }
+
+  /**
+   * Asserts that the current page text matches regex a number of times.
+   *
+   * @param int $count
+   *   The number of times the pattern is expected to be present.
+   * @param string $regex
+   *   The regex pattern.
+   * @param string $message
+   *   (Optional) the failure message.
+   */
+  public function pageTextMatchesCount(int $count, string $regex, string $message = ''): void {
+    $actual = preg_replace('/\s+/u', ' ', $this->session->getPage()->getText());
+    $matches = preg_match_all($regex, $actual);
+    if ($message === '') {
+      $message = "Failed asserting that the page matches the pattern '$regex' $count time(s), $matches found.";
+    }
+    $constraint = new IsIdentical($count);
+    Assert::assertThat($matches, $constraint, $message);
   }
 
   /**
@@ -69,12 +145,17 @@ class WebAssert extends MinkWebAssert {
    * @throws \Behat\Mink\Exception\ElementNotFoundException
    *   When the element doesn't exist.
    */
-  public function buttonExists($button, TraversableElement $container = NULL) {
+  public function buttonExists($button, ?TraversableElement $container = NULL) {
+    if (!is_string($button)) {
+      // @todo Trigger deprecation in
+      //   https://www.drupal.org/project/drupal/issues/3421105.
+      $button = (string) $button;
+    }
     $container = $container ?: $this->session->getPage();
     $node = $container->findButton($button);
 
     if ($node === NULL) {
-      throw new ElementNotFoundException($this->session, 'button', 'id|name|label|value', $button);
+      throw new ElementNotFoundException($this->session->getDriver(), 'button', 'id|name|label|value', $button);
     }
 
     return $node;
@@ -91,7 +172,7 @@ class WebAssert extends MinkWebAssert {
    * @throws \Behat\Mink\Exception\ExpectationException
    *   When the button exists.
    */
-  public function buttonNotExists($button, TraversableElement $container = NULL) {
+  public function buttonNotExists($button, ?TraversableElement $container = NULL) {
     $container = $container ?: $this->session->getPage();
     $node = $container->findButton($button);
 
@@ -112,7 +193,7 @@ class WebAssert extends MinkWebAssert {
    * @throws \Behat\Mink\Exception\ElementNotFoundException
    *   When the element doesn't exist.
    */
-  public function selectExists($select, TraversableElement $container = NULL) {
+  public function selectExists($select, ?TraversableElement $container = NULL) {
     $container = $container ?: $this->session->getPage();
     $node = $container->find('named', [
       'select',
@@ -120,7 +201,7 @@ class WebAssert extends MinkWebAssert {
     ]);
 
     if ($node === NULL) {
-      throw new ElementNotFoundException($this->session, 'select', 'id|name|label|value', $select);
+      throw new ElementNotFoundException($this->session->getDriver(), 'select', 'id|name|label|value', $select);
     }
 
     return $node;
@@ -142,7 +223,7 @@ class WebAssert extends MinkWebAssert {
    * @throws \Behat\Mink\Exception\ElementNotFoundException
    *   When the element doesn't exist.
    */
-  public function optionExists($select, $option, TraversableElement $container = NULL) {
+  public function optionExists($select, $option, ?TraversableElement $container = NULL) {
     $container = $container ?: $this->session->getPage();
     $select_field = $container->find('named', [
       'select',
@@ -150,13 +231,13 @@ class WebAssert extends MinkWebAssert {
     ]);
 
     if ($select_field === NULL) {
-      throw new ElementNotFoundException($this->session, 'select', 'id|name|label|value', $select);
+      throw new ElementNotFoundException($this->session->getDriver(), 'select', 'id|name|label|value', $select);
     }
 
-    $option_field = $select_field->find('named', ['option', $option]);
+    $option_field = $select_field->find('named_exact', ['option', $option]);
 
     if ($option_field === NULL) {
-      throw new ElementNotFoundException($this->session->getDriver(), 'select', 'id|name|label|value', $option);
+      throw new ElementNotFoundException($this->session->getDriver(), 'option', 'id|name|label|value', $option);
     }
 
     return $option_field;
@@ -175,7 +256,7 @@ class WebAssert extends MinkWebAssert {
    * @throws \Behat\Mink\Exception\ElementNotFoundException
    *   When the select element doesn't exist.
    */
-  public function optionNotExists($select, $option, TraversableElement $container = NULL) {
+  public function optionNotExists($select, $option, ?TraversableElement $container = NULL) {
     $container = $container ?: $this->session->getPage();
     $select_field = $container->find('named', [
       'select',
@@ -183,10 +264,10 @@ class WebAssert extends MinkWebAssert {
     ]);
 
     if ($select_field === NULL) {
-      throw new ElementNotFoundException($this->session, 'select', 'id|name|label|value', $select);
+      throw new ElementNotFoundException($this->session->getDriver(), 'select', 'id|name|label|value', $select);
     }
 
-    $option_field = $select_field->find('named', ['option', $option]);
+    $option_field = $select_field->find('named_exact', ['option', $option]);
 
     $this->assert($option_field === NULL, sprintf('An option "%s" exists in select "%s", but it should not.', $option, $select));
   }
@@ -227,7 +308,7 @@ class WebAssert extends MinkWebAssert {
    *   Thrown when element doesn't exist, or the link label is a different one.
    */
   public function linkExists($label, $index = 0, $message = '') {
-    $message = ($message ? $message : strtr('Link with label %label found.', ['%label' => $label]));
+    $message = ($message ? $message : strtr('Link with label %label not found.', ['%label' => $label]));
     $links = $this->session->getPage()->findAll('named', ['link', $label]);
     $this->assert(!empty($links[$index]), $message);
   }
@@ -250,7 +331,7 @@ class WebAssert extends MinkWebAssert {
    *   Thrown when element doesn't exist, or the link label is a different one.
    */
   public function linkExistsExact($label, $index = 0, $message = '') {
-    $message = ($message ? $message : strtr('Link with label %label found.', ['%label' => $label]));
+    $message = ($message ? $message : strtr('Link with label %label not found.', ['%label' => $label]));
     $links = $this->session->getPage()->findAll('named_exact', ['link', $label]);
     $this->assert(!empty($links[$index]), $message);
   }
@@ -271,7 +352,7 @@ class WebAssert extends MinkWebAssert {
    *   Thrown when element doesn't exist, or the link label is a different one.
    */
   public function linkNotExists($label, $message = '') {
-    $message = ($message ? $message : strtr('Link with label %label not found.', ['%label' => $label]));
+    $message = ($message ? $message : strtr('Link with label %label found.', ['%label' => $label]));
     $links = $this->session->getPage()->findAll('named', ['link', $label]);
     $this->assert(empty($links), $message);
   }
@@ -292,7 +373,7 @@ class WebAssert extends MinkWebAssert {
    *   Thrown when element doesn't exist, or the link label is a different one.
    */
   public function linkNotExistsExact($label, $message = '') {
-    $message = ($message ? $message : strtr('Link with label %label not found.', ['%label' => $label]));
+    $message = ($message ? $message : strtr('Link with label %label found.', ['%label' => $label]));
     $links = $this->session->getPage()->findAll('named_exact', ['link', $label]);
     $this->assert(empty($links), $message);
   }
@@ -306,16 +387,41 @@ class WebAssert extends MinkWebAssert {
    *   Link position counting from zero.
    * @param string $message
    *   (optional) A message to display with the assertion. Do not translate
-   *   messages: use \Drupal\Component\Render\FormattableMarkup to embed
-   *   variables in the message text, not t(). If left blank, a default message
-   *   will be displayed.
+   *   messages with t(). Use double quotes and embed variables directly in
+   *   message text, or use sprintf() if necessary. Avoid the use of
+   *   \Drupal\Component\Render\FormattableMarkup unless you cast the object to
+   *   a string. If left blank, a default message will be displayed.
    *
    * @throws \Behat\Mink\Exception\ExpectationException
    *   Thrown when element doesn't exist, or the link label is a different one.
    */
   public function linkByHrefExists($href, $index = 0, $message = '') {
     $xpath = $this->buildXPathQuery('//a[contains(@href, :href)]', [':href' => $href]);
-    $message = ($message ? $message : strtr('Link containing href %href found.', ['%href' => $href]));
+    $message = ($message ? $message : strtr('No link containing href %href found.', ['%href' => $href]));
+    $links = $this->session->getPage()->findAll('xpath', $xpath);
+    $this->assert(!empty($links[$index]), $message);
+  }
+
+  /**
+   * Passes if a link with a given href is found.
+   *
+   * @param string $href
+   *   The full value of the 'href' attribute of the anchor tag.
+   * @param int $index
+   *   Link position counting from zero.
+   * @param string $message
+   *   (optional) A message to display with the assertion. Do not translate
+   *   messages with t(). Use double quotes and embed variables directly in
+   *   message text, or use sprintf() if necessary. Avoid the use of
+   *   \Drupal\Component\Render\FormattableMarkup unless you cast the object to
+   *   a string. If left blank, a default message will be displayed.
+   *
+   * @throws \Behat\Mink\Exception\ExpectationException
+   *   Thrown when element doesn't exist, or the link label is a different one.
+   */
+  public function linkByHrefExistsExact(string $href, int $index = 0, string $message = ''): void {
+    $xpath = $this->buildXPathQuery('//a[@href=:href]', [':href' => $href]);
+    $message = ($message ?: strtr('No link with href %href found.', ['%href' => $href]));
     $links = $this->session->getPage()->findAll('xpath', $xpath);
     $this->assert(!empty($links[$index]), $message);
   }
@@ -327,16 +433,39 @@ class WebAssert extends MinkWebAssert {
    *   The full or partial value of the 'href' attribute of the anchor tag.
    * @param string $message
    *   (optional) A message to display with the assertion. Do not translate
-   *   messages: use \Drupal\Component\Render\FormattableMarkup to embed
-   *   variables in the message text, not t(). If left blank, a default message
-   *   will be displayed.
+   *   messages with t(). Use double quotes and embed variables directly in
+   *   message text, or use sprintf() if necessary. Avoid the use of
+   *   \Drupal\Component\Render\FormattableMarkup unless you cast the object to
+   *   a string. If left blank, a default message will be displayed.
    *
    * @throws \Behat\Mink\Exception\ExpectationException
    *   Thrown when element doesn't exist, or the link label is a different one.
    */
   public function linkByHrefNotExists($href, $message = '') {
     $xpath = $this->buildXPathQuery('//a[contains(@href, :href)]', [':href' => $href]);
-    $message = ($message ? $message : strtr('No link containing href %href found.', ['%href' => $href]));
+    $message = ($message ? $message : strtr('Link containing href %href found.', ['%href' => $href]));
+    $links = $this->session->getPage()->findAll('xpath', $xpath);
+    $this->assert(empty($links), $message);
+  }
+
+  /**
+   * Passes if a link with a given href is not found.
+   *
+   * @param string $href
+   *   The full value of the 'href' attribute of the anchor tag.
+   * @param string $message
+   *   (optional) A message to display with the assertion. Do not translate
+   *   messages with t(). Use double quotes and embed variables directly in
+   *   message text, or use sprintf() if necessary. Avoid the use of
+   *   \Drupal\Component\Render\FormattableMarkup unless you cast the object to
+   *   a string. If left blank, a default message will be displayed.
+   *
+   * @throws \Behat\Mink\Exception\ExpectationException
+   *   Thrown when element doesn't exist, or the link label is a different one.
+   */
+  public function linkByHrefNotExistsExact(string $href, string $message = ''): void {
+    $xpath = $this->buildXPathQuery('//a[@href=:href]', [':href' => $href]);
+    $message = ($message ?: strtr('Link with href %href found.', ['%href' => $href]));
     $links = $this->session->getPage()->findAll('xpath', $xpath);
     $this->assert(empty($links), $message);
   }
@@ -423,7 +552,7 @@ class WebAssert extends MinkWebAssert {
    * @param string|object $text
    *   Text value. Any non-string value will be cast to string.
    *
-   * @throws ExpectationException
+   * @throws \Behat\Mink\Exception\ExpectationException
    */
   public function responseContains($text) {
     parent::responseContains((string) $text);
@@ -435,7 +564,7 @@ class WebAssert extends MinkWebAssert {
    * @param string|object $text
    *   Text value. Any non-string value will be cast to string.
    *
-   * @throws ExpectationException
+   * @throws \Behat\Mink\Exception\ExpectationException
    */
   public function responseNotContains($text) {
     parent::responseNotContains((string) $text);
@@ -476,7 +605,7 @@ class WebAssert extends MinkWebAssert {
    * @throws \Behat\Mink\Exception\ElementNotFoundException
    * @throws \Behat\Mink\Exception\ExpectationException
    */
-  public function fieldDisabled($field, TraversableElement $container = NULL) {
+  public function fieldDisabled($field, ?TraversableElement $container = NULL) {
     $container = $container ?: $this->session->getPage();
     $node = $container->findField($field);
 
@@ -505,7 +634,7 @@ class WebAssert extends MinkWebAssert {
    * @throws \Behat\Mink\Exception\ElementNotFoundException
    * @throws \Behat\Mink\Exception\ExpectationException
    */
-  public function fieldEnabled($field, TraversableElement $container = NULL) {
+  public function fieldEnabled($field, ?TraversableElement $container = NULL) {
     $container = $container ?: $this->session->getPage();
     $node = $container->findField($field);
 
@@ -533,7 +662,7 @@ class WebAssert extends MinkWebAssert {
    *
    * @throws \Behat\Mink\Exception\ElementNotFoundException
    */
-  public function hiddenFieldExists($field, TraversableElement $container = NULL) {
+  public function hiddenFieldExists($field, ?TraversableElement $container = NULL) {
     $container = $container ?: $this->session->getPage();
     if ($node = $container->find('hidden_field_selector', ['hidden_field', $field])) {
       return $node;
@@ -551,7 +680,7 @@ class WebAssert extends MinkWebAssert {
    *
    * @throws \Behat\Mink\Exception\ExpectationException
    */
-  public function hiddenFieldNotExists($field, TraversableElement $container = NULL) {
+  public function hiddenFieldNotExists($field, ?TraversableElement $container = NULL) {
     $container = $container ?: $this->session->getPage();
     $node = $container->find('hidden_field_selector', ['hidden_field', $field]);
     $this->assert($node === NULL, "A hidden field '$field' exists on this page, but it should not.");
@@ -570,7 +699,7 @@ class WebAssert extends MinkWebAssert {
    * @throws \Behat\Mink\Exception\ElementNotFoundException
    * @throws \Behat\Mink\Exception\ExpectationException
    */
-  public function hiddenFieldValueEquals($field, $value, TraversableElement $container = NULL) {
+  public function hiddenFieldValueEquals($field, $value, ?TraversableElement $container = NULL) {
     $node = $this->hiddenFieldExists($field, $container);
     $actual = $node->getValue();
     $regex = '/^' . preg_quote($value, '/') . '$/ui';
@@ -591,7 +720,7 @@ class WebAssert extends MinkWebAssert {
    * @throws \Behat\Mink\Exception\ElementNotFoundException
    * @throws \Behat\Mink\Exception\ExpectationException
    */
-  public function hiddenFieldValueNotEquals($field, $value, TraversableElement $container = NULL) {
+  public function hiddenFieldValueNotEquals($field, $value, ?TraversableElement $container = NULL) {
     $node = $this->hiddenFieldExists($field, $container);
     $actual = $node->getValue();
     $regex = '/^' . preg_quote($value, '/') . '$/ui';
@@ -608,22 +737,258 @@ class WebAssert extends MinkWebAssert {
    * @see \Behat\Mink\WebAssert::pageTextContains()
    */
   public function pageTextContainsOnce($text) {
-    $actual = $this->session->getPage()->getText();
-    $actual = preg_replace('/\s+/u', ' ', $actual);
     $regex = '/' . preg_quote($text, '/') . '/ui';
-    $count = preg_match_all($regex, $actual);
-    if ($count === 1) {
+    try {
+      $this->pageTextMatchesCount(1, $regex);
+    }
+    catch (AssertionFailedError $e) {
+      throw new ResponseTextException($e->getMessage(), $this->session->getDriver());
+    }
+  }
+
+  /**
+   * Asserts that each HTML ID is used for just a single element on the page.
+   *
+   * @throws \Behat\Mink\Exception\ExpectationException
+   */
+  public function pageContainsNoDuplicateId() {
+    $seen_ids = [];
+    foreach ($this->session->getPage()->findAll('xpath', '//*[@id]') as $element) {
+      $id = $element->getAttribute('id');
+      if (isset($seen_ids[$id])) {
+        throw new ExpectationException(sprintf('The page contains a duplicate HTML ID "%s".', $id), $this->session->getDriver());
+      }
+      $seen_ids[$id] = TRUE;
+    }
+  }
+
+  /**
+   * Checks that current session address is equals to provided one.
+   *
+   * @param string|\Drupal\Core\Url $page
+   *   A url string, or object.
+   *
+   * @return void
+   *
+   * @throws \Behat\Mink\Exception\ExpectationException
+   */
+  public function addressEquals(string|Url $page) {
+    $expected = $this->cleanUrl($page, TRUE);
+    $actual = $this->cleanUrl($this->session->getCurrentUrl(), str_contains($expected, '?'));
+
+    $this->assert($actual === $expected, sprintf('Current page is "%s", but "%s" expected.', $actual, $expected));
+  }
+
+  /**
+   * Checks that current session address is not equals to provided one.
+   *
+   * @param string|\Drupal\Core\Url $page
+   *   A url string, or object.
+   *
+   * @throws \Behat\Mink\Exception\ExpectationException
+   */
+  public function addressNotEquals(string|Url $page) {
+    $expected = $this->cleanUrl($page, TRUE);
+    $actual = $this->cleanUrl($this->session->getCurrentUrl(), str_contains($expected, '?'));
+
+    $this->assert($actual !== $expected, sprintf('Current page is "%s", but should not be.', $actual));
+  }
+
+  /**
+   * Asserts a specific element's text equals an expected text.
+   *
+   * @param string $selectorType
+   *   Element selector type (css, xpath).
+   * @param string|array $selector
+   *   Element selector.
+   * @param string $text
+   *   Expected text.
+   */
+  public function elementTextEquals(string $selectorType, $selector, string $text): void {
+    $selector_string = is_array($selector) ? '[' . implode(', ', $selector) . ']' : $selector;
+    $message = "Failed asserting that the text of the element identified by '$selector_string' equals '$text'.";
+    $constraint = new IsEqual($text);
+    Assert::assertThat($this->elementExists($selectorType, $selector)->getText(), $constraint, $message);
+  }
+
+  /**
+   * Asserts that a status message exists.
+   *
+   * @param string|null $type
+   *   The optional message type: status, error, or warning.
+   */
+  public function statusMessageExists(?string $type = NULL): void {
+    $selector = $this->buildStatusMessageSelector(NULL, $type);
+    try {
+      $this->elementExists('xpath', $selector);
+    }
+    catch (ExpectationException $e) {
+      Assert::fail($e->getMessage());
+    }
+  }
+
+  /**
+   * Asserts that a status message does not exist.
+   *
+   * @param string|null $type
+   *   The optional message type: status, error, or warning.
+   */
+  public function statusMessageNotExists(?string $type = NULL): void {
+    $selector = $this->buildStatusMessageSelector(NULL, $type);
+    try {
+      $this->elementNotExists('xpath', $selector);
+    }
+    catch (ExpectationException $e) {
+      Assert::fail($e->getMessage());
+    }
+  }
+
+  /**
+   * Asserts that a status message containing a given string exists.
+   *
+   * @param string $message
+   *   The partial message to assert.
+   * @param string|null $type
+   *   The optional message type: status, error, or warning.
+   */
+  public function statusMessageContains(string $message, ?string $type = NULL): void {
+    $selector = $this->buildStatusMessageSelector($message, $type);
+    try {
+      $this->elementExists('xpath', $selector);
+    }
+    catch (ExpectationException $e) {
+      Assert::fail($e->getMessage());
+    }
+  }
+
+  /**
+   * Asserts that a status message containing a given string does not exist.
+   *
+   * @param string $message
+   *   The partial message to assert.
+   * @param string|null $type
+   *   The optional message type: status, error, or warning.
+   */
+  public function statusMessageNotContains(string $message, ?string $type = NULL): void {
+    $selector = $this->buildStatusMessageSelector($message, $type);
+    try {
+      $this->elementNotExists('xpath', $selector);
+    }
+    catch (ExpectationException $e) {
+      Assert::fail($e->getMessage());
+    }
+  }
+
+  /**
+   * Builds a xpath selector for a message with given type and text.
+   *
+   * The selector is designed to work with the status-messages.html.twig
+   * template in the system module.
+   *
+   * See Drupal\Core\Render\Element\StatusMessages for aria label definition.
+   *
+   * @param string|null $message
+   *   The optional message or partial message to assert.
+   * @param string|null $type
+   *   The optional message type: status, error, or warning.
+   *
+   * @return string
+   *   The xpath selector for the message.
+   *
+   * @throws \InvalidArgumentException
+   *   Thrown when $type is not an allowed type.
+   */
+  protected function buildStatusMessageSelector(?string $message = NULL, ?string $type = NULL): string {
+    $allowed_types = [
+      'status',
+      'error',
+      'warning',
+      NULL,
+    ];
+    if (!in_array($type, $allowed_types, TRUE)) {
+      throw new \InvalidArgumentException(sprintf("If a status message type is specified, the allowed values are 'status', 'error', 'warning'. The value provided was '%s'.", $type));
+    }
+    $selector = '//div[@data-drupal-messages]';
+    $aria_label = NULL;
+    switch ($type) {
+      case 'status':
+        $aria_label = 'Status message';
+        break;
+
+      case 'error':
+        $aria_label = 'Error message';
+        break;
+
+      case 'warning':
+        $aria_label = 'Warning message';
+    }
+
+    if ($message && $aria_label && $type) {
+      $selector = $this->buildXPathQuery($selector . '//div[(contains(@aria-label, :aria_label) or contains(@aria-labelledby, :type)) and contains(., :message)]', [
+        // Value of the 'aria-label' attribute, used in Stark.
+        ':aria_label' => $aria_label,
+        // Value of the 'aria-labelledby' attribute, used in Claro and Olivero.
+        ':type' => $type,
+        ':message' => $message,
+      ]);
+    }
+    elseif ($message) {
+      $selector = $this->buildXPathQuery($selector . '//div[contains(., :message)]', [
+        ':message' => $message,
+      ]);
+    }
+    elseif ($aria_label) {
+      $selector = $this->buildXPathQuery($selector . '//div[@aria-label=:aria_label]', [
+        ':aria_label' => $aria_label,
+      ]);
+    }
+
+    return $selector;
+  }
+
+  /**
+   * {@inheritdoc}
+   */
+  public function responseHeaderEquals($name, $value) {
+    if (!is_string($name)) {
+      // @todo Trigger deprecation in
+      //   https://www.drupal.org/project/drupal/issues/3421105.
+      $name = (string) $name;
+    }
+    if ($value === NULL) {
+      // @todo Trigger deprecation in
+      //   https://www.drupal.org/project/drupal/issues/3421105.
+      $this->responseHeaderDoesNotExist($name);
       return;
     }
-
-    if ($count > 1) {
-      $message = sprintf('The text "%s" appears in the text of this page more than once, but it should not.', $text);
-    }
-    else {
-      $message = sprintf('The text "%s" was not found anywhere in the text of the current page.', $text);
+    if (!is_string($value)) {
+      $value = (string) $value;
     }
+    parent::responseHeaderEquals($name, $value);
+  }
 
-    throw new ResponseTextException($message, $this->session->getDriver());
+  /**
+   * {@inheritdoc}
+   */
+  public function pageTextContains($text) {
+    if (!is_string($text)) {
+      // @todo Trigger deprecation in
+      //   https://www.drupal.org/project/drupal/issues/3421105.
+      $text = (string) $text;
+    }
+    parent::pageTextContains($text);
+  }
+
+  /**
+   * {@inheritdoc}
+   */
+  public function fieldValueEquals(string $field, $value, ?TraversableElement $container = NULL) {
+    if (!is_string($value)) {
+      // @todo Trigger deprecation in
+      //   https://www.drupal.org/project/drupal/issues/3421105.
+      $value = (string) $value;
+    }
+    parent::fieldValueEquals($field, $value, $container);
   }
 
 }
